[Libreoffice-commits] .: sd/Module_sd.mk

2012-01-25 Thread Markus Mohrhard
 sd/Module_sd.mk |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

New commits:
commit 925907767cc63c1e5d6414e215f671a0b9f8a28a
Author: Markus Mohrhard 
Date:   Thu Jan 26 01:40:23 2012 +0100

disable sd's regression test again

diff --git a/sd/Module_sd.mk b/sd/Module_sd.mk
index edc6f25..b1dbe0c 100644
--- a/sd/Module_sd.mk
+++ b/sd/Module_sd.mk
@@ -52,7 +52,8 @@ endif
 
 $(eval $(call gb_Module_add_subsequentcheck_targets,sd,\
 JunitTest_sd_unoapi \
-CppunitTest_sd_regression_test \
 ))
 
+# Still a problem in line 16
+#CppunitTest_sd_regression_test \
 # vim: set noet sw=4 ts=4:
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: qadevOOo/tests sc/qa

2012-01-25 Thread Markus Mohrhard
 dev/null   |binary
 qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java  |6 +++---
 qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java |6 +++---
 sc/qa/unoapi/sc.sce|4 ++--
 sc/qa/unoapi/testdocuments/ScDDELinksObj.ods   |binary
 5 files changed, 8 insertions(+), 8 deletions(-)

New commits:
commit 80eecd4677c5a1b61be1a34eea4bbecdc7e95e80
Author: Markus Mohrhard 
Date:   Thu Jan 26 01:32:32 2012 +0100

switch subsequenttest testdocs from sdc to ods, fdo#43376

diff --git a/sc/qa/unoapi/sc.sce b/sc/qa/unoapi/sc.sce
index dabb97a..1a38b3a 100644
--- a/sc/qa/unoapi/sc.sce
+++ b/sc/qa/unoapi/sc.sce
@@ -37,8 +37,8 @@
 -o sc.ScChartObj
 -o sc.ScChartsObj
 -o sc.ScConsolidationDescriptor
-# fdo43376 -o sc.ScDDELinkObj
-# fdo43376 -o sc.ScDDELinksObj
+-o sc.ScDDELinkObj
+-o sc.ScDDELinksObj
 -o sc.ScDataPilotFieldGroupItemObj
 -o sc.ScDataPilotFieldGroupObj
 -o sc.ScDataPilotFieldGroupsObj
diff --git a/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods 
b/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods
new file mode 100644
index 000..01c11e3
Binary files /dev/null and b/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods differ
diff --git a/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc 
b/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc
deleted file mode 100644
index 1abdbf4..000
Binary files a/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc and /dev/null differ
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: xmloff/source

2012-01-25 Thread Olivier Hallot
 xmloff/source/forms/controlpropertyhdl.cxx |6 +-
 xmloff/source/forms/elementexport.cxx  |   24 +-
 xmloff/source/forms/elementimport.cxx  |   48 ++---
 xmloff/source/forms/eventexport.cxx|4 -
 xmloff/source/forms/eventimport.cxx|2 
 xmloff/source/forms/formcellbinding.cxx|4 -
 xmloff/source/forms/layerexport.cxx|4 -
 xmloff/source/forms/layerimport.cxx|   10 ++--
 xmloff/source/forms/property_meta_data.cxx |   10 ++--
 xmloff/source/forms/propertyexport.cxx |   20 
 xmloff/source/forms/propertyimport.cxx |   10 ++--
 xmloff/source/meta/xmlmetae.cxx|   14 +++---
 xmloff/source/meta/xmlmetai.cxx|4 -
 xmloff/source/meta/xmlversion.cxx  |4 -
 xmloff/source/script/XMLStarBasicExportHandler.cxx |2 
 xmloff/source/script/xmlbasici.cxx |2 
 xmloff/source/style/DashStyle.cxx  |4 -
 xmloff/source/style/FillStyleContext.cxx   |4 -
 xmloff/source/style/GradientStyle.cxx  |4 -
 xmloff/source/style/HatchStyle.cxx |4 -
 xmloff/source/style/ImageStyle.cxx |8 +--
 xmloff/source/style/MarkerStyle.cxx|4 -
 xmloff/source/style/PageMasterImportContext.cxx|2 
 xmloff/source/style/PageMasterPropHdl.cxx  |   12 ++---
 xmloff/source/style/TransGradientStyle.cxx |4 -
 xmloff/source/style/XMLBackgroundImageContext.cxx  |6 +-
 xmloff/source/style/XMLBackgroundImageExport.cxx   |8 +--
 xmloff/source/style/XMLFontAutoStylePool.cxx   |4 -
 xmloff/source/style/XMLPageExport.cxx  |4 -
 xmloff/source/style/bordrhdl.cxx   |2 
 xmloff/source/style/cdouthdl.cxx   |2 
 xmloff/source/style/chrhghdl.cxx   |6 +-
 xmloff/source/style/chrlohdl.cxx   |4 -
 xmloff/source/style/csmaphdl.cxx   |2 
 34 files changed, 126 insertions(+), 126 deletions(-)

New commits:
commit 3dbb89e5a39e7811d2fc0c1fbad012c3d565396b
Author: Olivier Hallot 
Date:   Wed Jan 25 21:59:48 2012 -0200

Fix for fdo43460 Part XLVIII getLength() to isEmpty()

Part XLVIII
Modules
xmloff (part 2)

diff --git a/xmloff/source/forms/controlpropertyhdl.cxx 
b/xmloff/source/forms/controlpropertyhdl.cxx
index 3c8b0fc..5442a55 100644
--- a/xmloff/source/forms/controlpropertyhdl.cxx
+++ b/xmloff/source/forms/controlpropertyhdl.cxx
@@ -245,7 +245,7 @@ namespace xmloff
 sal_uInt16 nStyle = 1;
 
 while   (   aTokens.getNextToken(sToken)// have a new token
-&&  (0 != sToken.getLength())   // really have a new token
+&&  (!sToken.isEmpty())   // really have a new token
 )
 {
 // try interpreting the token as border style
@@ -304,7 +304,7 @@ namespace xmloff
 if ( !bSuccess )
 return sal_False;
 
-if ( _rStrExpValue.getLength() )
+if ( !_rStrExpValue.isEmpty() )
 _rStrExpValue += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( " " 
) );
 _rStrExpValue += aOut.makeStringAndClear();
 
@@ -343,7 +343,7 @@ namespace xmloff
 }
 _rStrExpValue = aResult.makeStringAndClear();
 
-return _rStrExpValue.getLength() != 0;
+return !_rStrExpValue.isEmpty();
 }
 
 //=
diff --git a/xmloff/source/forms/elementexport.cxx 
b/xmloff/source/forms/elementexport.cxx
index fcc3efa..863d99a 100644
--- a/xmloff/source/forms/elementexport.cxx
+++ b/xmloff/source/forms/elementexport.cxx
@@ -316,7 +316,7 @@ namespace xmloff
 // the control id
 if (CCA_CONTROL_ID & m_nIncludeCommon)
 {
-OSL_ENSURE(m_sControlId.getLength(), 
"OControlExport::exportInnerAttributes: have no control id for the control!");
+OSL_ENSURE(!m_sControlId.isEmpty(), 
"OControlExport::exportInnerAttributes: have no control id for the control!");
 m_rContext.getGlobalContext().AddAttributeIdLegacy(
 XML_NAMESPACE_FORM, m_sControlId);
 #if OSL_DEBUG_LEVEL > 0
@@ -799,7 +799,7 @@ namespace xmloff
 // the target frame
 if (m_nIncludeCommon & CCA_FOR)
 {
-if (m_sReferringControls.getLength())
+if (!m_sReferringControls.isEmpty())
 {   // there is at least one control referring to the one we're 
handling currently
 AddAttribute(
 
OAttributeMetaData::getCommonControlAttributeNamespace(CCA_FOR),
@@ -1095,7 +1095,7 @@ namespace xmloff
 else
 OSL_FAIL( "OControlExport::exportSpecialAttributes: not 
property which can be mapped to step-size att

[Libreoffice-commits] .: Branch 'feature/android' - android/qa

2012-01-25 Thread Michael Meeks
 android/qa/desktop/Makefile |1 +
 1 file changed, 1 insertion(+)

New commits:
commit 0f32f98564f8e0e66bc2d2ee5c55406930007044
Author: Michael Meeks 
Date:   Wed Jan 25 22:41:41 2012 +

android: add missing deployment component

diff --git a/android/qa/desktop/Makefile b/android/qa/desktop/Makefile
index 1dd0d83..876c432 100644
--- a/android/qa/desktop/Makefile
+++ b/android/qa/desktop/Makefile
@@ -109,6 +109,7 @@ copy-stuff: buildrcs
  bootstrap.uno \
  comphelpgcc3 \
  configmgr.uno \
+ deployment \
  deploymentmisclo \
  fileacc \
  fontconfig \
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - vcl/android

2012-01-25 Thread Michael Meeks
 vcl/android/androidinst.cxx |  103 
 1 file changed, 76 insertions(+), 27 deletions(-)

New commits:
commit 0def387f351b7e67c2f45474105333c4cb4f55dc
Author: Michael Meeks 
Date:   Wed Jan 25 22:09:39 2012 +

android: add first cut of frame contents blitting, and error dialog

diff --git a/vcl/android/androidinst.cxx b/vcl/android/androidinst.cxx
index b4ea9e0..4772a74 100644
--- a/vcl/android/androidinst.cxx
+++ b/vcl/android/androidinst.cxx
@@ -74,44 +74,70 @@ static rtl::OString KeyMetaStateToString(int32_t nFlags)
 }
 
 static void BlitFrameRegionToWindow(ANativeWindow *pWindow,
-const basebmp::BitmapDeviceSharedPtr& /* 
aDev */,
-const ARect &aSrcRect,
+const basebmp::BitmapDeviceSharedPtr& aDev,
+const ARect &rSrcRect,
 int nDestX, int nDestY)
 {
-fprintf (stderr, "Blit frame src %d,%d->%d,%d to positoon %d, %d\n",
- aSrcRect.left, aSrcRect.top, aSrcRect.right, aSrcRect.bottom,
+fprintf (stderr, "Blit frame src %d,%d->%d,%d to position %d, %d\n",
+ rSrcRect.left, rSrcRect.top, rSrcRect.right, rSrcRect.bottom,
  nDestX, nDestY);
-#if 1
 ARect aRect;
-ANativeWindow_Buffer aBuffer;
-memset ((void *)&aBuffer, 0, sizeof (aBuffer));
-int32_t nRet = ANativeWindow_lock(pWindow, &aBuffer, &aRect);
+ANativeWindow_Buffer aOutBuffer;
+memset ((void *)&aOutBuffer, 0, sizeof (aOutBuffer));
+int32_t nRet = ANativeWindow_lock(pWindow, &aOutBuffer, &aRect);
 fprintf (stderr, "locked window %d returned rect: %d,%d->%d,%d "
  "buffer: %dx%d stride %d, format %d, bits %p\n",
  nRet, aRect.left, aRect.top, aRect.right, aRect.bottom,
- aBuffer.width, aBuffer.height, aBuffer.stride,
- aBuffer.format, aBuffer.bits);
-if (aBuffer.bits)
+ aOutBuffer.width, aOutBuffer.height, aOutBuffer.stride,
+ aOutBuffer.format, aOutBuffer.bits);
+if (aOutBuffer.bits == NULL)
 {
-// hard-code / guess at a format ...
-int32_t *p = (int32_t *)aBuffer.bits;
-for (int32_t y = 0; y < aBuffer.height; y++)
+fprintf (stderr, "no buffer for locked window\n");
+ANativeWindow_unlockAndPost(pWindow);
+return;
+}
+
+// FIXME: do some cropping goodness on aSrcRect to ensure no overflows etc.
+ARect aSrcRect = rSrcRect;
+sal_Int32 nStride = aDev->getScanlineStride();
+basebmp::RawMemorySharedArray aSrcData = aDev->getBuffer();
+unsigned char *pSrc = aSrcData.get();
+
+for (unsigned int y = 0; y < (unsigned int)(aSrcRect.bottom - 
aSrcRect.top); y++)
+{
+unsigned char *sp = ( pSrc + nStride * (y + aSrcRect.top) +
+  aSrcRect.left * 3 /* src pixel size */ );
+unsigned char *dp = ( (unsigned char *)aOutBuffer.bits +
+  aOutBuffer.stride * (y + nDestY) +
+  nDestX * 4 /* dest pixel size */ );
+for (unsigned int x = 0; x < (unsigned int)(aSrcRect.right - 
aSrcRect.left); x++)
 {
-for (int32_t x = 0; x < aBuffer.stride / 4; x++)
-*p++ = (y << 24) + x;
+dp[x*4 + 0] = sp[x*3 + 0]; // B
+dp[x*4 + 1] = sp[x*3 + 1]; // G
+dp[x*4 + 2] = sp[x*3 + 2]; // R
+dp[x*4 + 3] = 255; // A
 }
 }
-ANativeWindow_unlockAndPost(pWindow);
-fprintf (stderr, "done render!\n");
+fprintf (stderr, "done blit!\n");
+#if 0
+// hard-code / guess at a format ...
+int32_t *p = (int32_t *)aBuffer.bits;
+for (int32_t y = 0; y < aBuffer.height; y++)
+{
+for (int32_t x = 0; x < aBuffer.stride / 4; x++)
+*p++ = (y << 24) + x;
+}
 #endif
 
+ANativeWindow_unlockAndPost(pWindow);
+fprintf (stderr, "done render!\n");
 }
 
 void AndroidSalInstance::BlitFrameToWindow(ANativeWindow *pWindow,
const 
basebmp::BitmapDeviceSharedPtr& aDev)
 {
 basegfx::B2IVector aDevSize = aDev->getSize();
-ARect aWhole = { 0, 0, aDevSize.getX(), aDevSize.getY() };
+ARect aWhole = { 0, 0, 400, 400 }; // FIXME: aDevSize.getX(), 
aDevSize.getY() };
 BlitFrameRegionToWindow(pWindow, aDev, aWhole, 0, 0);
 }
 
@@ -211,6 +237,8 @@ int32_t AndroidSalInstance::onInputEvent (struct 
android_app* app, AInputEvent*
 
 AndroidSalInstance *AndroidSalInstance::getInstance()
 {
+if (!ImplGetSVData())
+return NULL;
 AndroidSalData *pData = static_cast(ImplGetSVData()->mpSalData);
 if (!pData)
 return NULL;
@@ -299,14 +327,7 @@ public:
 virtual int ShowNativeDialog( const rtl::OUString& rTitle,
   const rtl::OUString& rMessage,
   const std::list< rtl::OUString >& rB

[Libreoffice-commits] .: Branch 'libreoffice-3-5-0' - sc/source

2012-01-25 Thread Markus Mohrhard
 sc/source/core/data/dpoutput.cxx |   14 +++---
 1 file changed, 11 insertions(+), 3 deletions(-)

New commits:
commit be8e049d01f05773ac595b5ee32b262540381a44
Author: Kohei Yoshida 
Date:   Tue Jan 24 16:32:10 2012 -0500

fdo#45067: Differentiate numeric and non-numeric field member values.

Signed-off-by: Markus Mohrhard 

diff --git a/sc/source/core/data/dpoutput.cxx b/sc/source/core/data/dpoutput.cxx
index 990e212..32179e3 100644
--- a/sc/source/core/data/dpoutput.cxx
+++ b/sc/source/core/data/dpoutput.cxx
@@ -795,10 +795,18 @@ void ScDPOutput::HeaderCell( SCCOL nCol, SCROW nRow, 
SCTAB nTab,
 
 if ( nFlags & sheet::MemberResultFlags::HASMEMBER )
 {
-// Avoid unwanted automatic format detection.
+bool bNumeric = (nFlags & sheet::MemberResultFlags::NUMERIC) != 0;
 ScSetStringParam aParam;
-aParam.mbDetectNumberFormat = false;
-aParam.mbSetTextCellFormat = true;
+if (bNumeric)
+{
+aParam.mbDetectNumberFormat = true;
+aParam.mbSetTextCellFormat = false;
+}
+else
+{
+aParam.mbDetectNumberFormat = false;
+aParam.mbSetTextCellFormat = true;
+}
 pDoc->SetString(nCol, nRow, nTab, rData.Caption, &aParam);
 }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - vcl/inc

2012-01-25 Thread Michael Meeks
 vcl/inc/android/androidinst.hxx |   13 -
 vcl/inc/headless/svpframe.hxx   |4 ++--
 2 files changed, 14 insertions(+), 3 deletions(-)

New commits:
commit 32af4e15048e53b223294ad33ac428f992bfd0eb
Author: Michael Meeks 
Date:   Wed Jan 25 21:13:36 2012 +

android: missing header pieces

diff --git a/vcl/inc/android/androidinst.hxx b/vcl/inc/android/androidinst.hxx
index 3b026b0..aec2735 100644
--- a/vcl/inc/android/androidinst.hxx
+++ b/vcl/inc/android/androidinst.hxx
@@ -30,22 +30,33 @@
 #ifndef ANDROID_SALINST_H
 #define ANDROID_SALINST_H
 
+#include 
+#include 
 #include 
+#include 
 
 class AndroidSalInstance : public SvpSalInstance
 {
+void RedrawWindows(ANativeWindow *pWindow);
+void BlitFrameToWindow(ANativeWindow *pWindow,
+   const basebmp::BitmapDeviceSharedPtr& aDev);
 public:
 AndroidSalInstance( SalYieldMutex *pMutex );
 virtual ~AndroidSalInstance();
+static AndroidSalInstance *getInstance();
 
 virtual SalSystem* CreateSalSystem();
 
 // mainloop pieces
 virtual void Wakeup();
 virtual bool AnyInput( sal_uInt16 nType );
+
+// incoming android event handlers:
+voidonAppCmd (struct android_app* app, int32_t cmd);
+int32_t onInputEvent (struct android_app* app, AInputEvent* event);
 protected:
 virtual void DoReleaseYield( int nTimeoutMS );
-struct android_app *app;
+struct android_app *mpApp;
 };
 
 #endif // ANDROID_SALINST_H
diff --git a/vcl/inc/headless/svpframe.hxx b/vcl/inc/headless/svpframe.hxx
index 5f88e64..37e0ae9 100644
--- a/vcl/inc/headless/svpframe.hxx
+++ b/vcl/inc/headless/svpframe.hxx
@@ -41,9 +41,9 @@ class SvpSalGraphics;
 class SvpSalFrame : public SalFrame, public SvpElement
 {
 SvpSalInstance* m_pInstance;
-SvpSalFrame*m_pParent;   // pointer to parent frame
+SvpSalFrame*m_pParent;   // pointer to parent 
frame
 std::list< SvpSalFrame* >   m_aChildren; // List of child 
frames
-sal_uLong m_nStyle;
+sal_uLong   m_nStyle;
 boolm_bVisible;
 longm_nMinWidth;
 longm_nMinHeight;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - 2 commits - sal/android sal/Library_lo-bootstrap.mk vcl/android

2012-01-25 Thread Michael Meeks
 sal/Library_lo-bootstrap.mk |5 +
 sal/android/lo-bootstrap.c  |8 +-
 vcl/android/androidinst.cxx |  161 +---
 3 files changed, 118 insertions(+), 56 deletions(-)

New commits:
commit b3904a718bbf278034afb231df3473e7138b05ac
Author: Michael Meeks 
Date:   Wed Jan 25 21:07:24 2012 +

android: move event handling to members of SalInstance

rename app -> mpApp and initial handling of frames, we will need
a mini window-manager in here, most likely.

diff --git a/vcl/android/androidinst.cxx b/vcl/android/androidinst.cxx
index e6df7fb..b4ea9e0 100644
--- a/vcl/android/androidinst.cxx
+++ b/vcl/android/androidinst.cxx
@@ -30,13 +30,19 @@
 #include 
 #include 
 #include 
-#include 
 #include 
-#include 
 #include 
 #include 
 #include 
 
+class AndroidSalData : public SalGenericData
+{
+public:
+AndroidSalData( SalInstance *pInstance ) : SalGenericData( 
SAL_DATA_ANDROID, pInstance ) {}
+virtual void ErrorTrapPush() {}
+virtual bool ErrorTrapPop( bool ) { return false; }
+};
+
 static rtl::OString MotionEdgeFlagsToString(int32_t nFlags)
 {
 rtl::OStringBuffer aStr;
@@ -67,13 +73,62 @@ static rtl::OString KeyMetaStateToString(int32_t nFlags)
 return aStr.makeStringAndClear();
 }
 
-int32_t AMotionEvent_getEdgeFlags(const AInputEvent* motion_event);
+static void BlitFrameRegionToWindow(ANativeWindow *pWindow,
+const basebmp::BitmapDeviceSharedPtr& /* 
aDev */,
+const ARect &aSrcRect,
+int nDestX, int nDestY)
+{
+fprintf (stderr, "Blit frame src %d,%d->%d,%d to positoon %d, %d\n",
+ aSrcRect.left, aSrcRect.top, aSrcRect.right, aSrcRect.bottom,
+ nDestX, nDestY);
+#if 1
+ARect aRect;
+ANativeWindow_Buffer aBuffer;
+memset ((void *)&aBuffer, 0, sizeof (aBuffer));
+int32_t nRet = ANativeWindow_lock(pWindow, &aBuffer, &aRect);
+fprintf (stderr, "locked window %d returned rect: %d,%d->%d,%d "
+ "buffer: %dx%d stride %d, format %d, bits %p\n",
+ nRet, aRect.left, aRect.top, aRect.right, aRect.bottom,
+ aBuffer.width, aBuffer.height, aBuffer.stride,
+ aBuffer.format, aBuffer.bits);
+if (aBuffer.bits)
+{
+// hard-code / guess at a format ...
+int32_t *p = (int32_t *)aBuffer.bits;
+for (int32_t y = 0; y < aBuffer.height; y++)
+{
+for (int32_t x = 0; x < aBuffer.stride / 4; x++)
+*p++ = (y << 24) + x;
+}
+}
+ANativeWindow_unlockAndPost(pWindow);
+fprintf (stderr, "done render!\n");
+#endif
 
-extern "C" {
-void onAppCmd_cb (struct android_app* app, int32_t cmd)
+}
+
+void AndroidSalInstance::BlitFrameToWindow(ANativeWindow *pWindow,
+   const 
basebmp::BitmapDeviceSharedPtr& aDev)
+{
+basegfx::B2IVector aDevSize = aDev->getSize();
+ARect aWhole = { 0, 0, aDevSize.getX(), aDevSize.getY() };
+BlitFrameRegionToWindow(pWindow, aDev, aWhole, 0, 0);
+}
+
+void AndroidSalInstance::RedrawWindows(ANativeWindow *pWindow)
+{
+std::list< SalFrame* >::const_iterator it;
+for ( it = getFrames().begin(); it != getFrames().end(); it++ )
 {
+SvpSalFrame *pFrame = static_cast(*it);
+BlitFrameToWindow (pWindow, pFrame->getDevice());
+}
+}
+
+void AndroidSalInstance::onAppCmd (struct android_app* app, int32_t cmd)
+{
 fprintf (stderr, "app cmd for app %p, cmd %d\n", app, cmd);
-ANativeWindow *pWindow = app->window;
+ANativeWindow *pWindow = mpApp->window;
 switch (cmd) {
 case APP_CMD_INIT_WINDOW:
 {
@@ -83,26 +138,8 @@ extern "C" {
 fprintf (stderr, "we have an app window ! %p %dx%x (%d)\n",
  pWindow, aRect.right, aRect.bottom,
  ANativeWindow_getFormat(pWindow));
-ANativeWindow_Buffer aBuffer;
-memset ((void *)&aBuffer, 0, sizeof (aBuffer));
-int32_t nRet = ANativeWindow_lock(pWindow, &aBuffer, &aRect);
-fprintf (stderr, "locked window %d returned rect: %d,%d->%d,%d "
- "buffer: %dx%d stride %d, format %d, bits %p\n",
- nRet, aRect.left, aRect.top, aRect.right, aRect.bottom,
- aBuffer.width, aBuffer.height, aBuffer.stride,
- aBuffer.format, aBuffer.bits);
-if (aBuffer.bits)
-{
-// hard-code / guess at a format ...
-int32_t *p = (int32_t *)aBuffer.bits;
-for (int32_t y = 0; y < aBuffer.height; y++)
-{
-for (int32_t x = 0; x < aBuffer.stride / 4; x++)
-*p++ = (y << 24) + x;
-}
-}
-ANativeWindow_unlockAndPost(pWindow);
-fprintf (stderr, "done render!\n");
+
+RedrawWindows

[Libreoffice-commits] .: Branch 'libreoffice-3-5' - sc/source

2012-01-25 Thread Kohei Yoshida
 sc/source/ui/unoobj/cellsuno.cxx |4 +---
 1 file changed, 1 insertion(+), 3 deletions(-)

New commits:
commit 16291662332dae29af38e70dd6b327324c2d5bd7
Author: Markus Mohrhard 
Date:   Wed Jan 25 21:03:24 2012 +0100

ScTableSheetObj::findAll does not return the correct range, fdo#43462

Signed-off-by: Kohei Yoshida 

diff --git a/sc/source/ui/unoobj/cellsuno.cxx b/sc/source/ui/unoobj/cellsuno.cxx
index ca59caf..fc38a45 100644
--- a/sc/source/ui/unoobj/cellsuno.cxx
+++ b/sc/source/ui/unoobj/cellsuno.cxx
@@ -3907,10 +3907,8 @@ uno::Reference SAL_CALL 
ScCellRangesBase::findAll(
 *pSearchItem, nCol, nRow, nTab, aMark, aMatchedRanges, 
aDummyUndo, NULL);
 if (bFound)
 {
-ScRangeList aNewRanges;
-aMark.FillRangeListWithMarks( &aNewRanges, sal_True );
 //  bei findAll immer CellRanges, egal wieviel gefunden 
wurde
-xRet.set(new ScCellRangesObj( pDocShell, aNewRanges ));
+xRet.set(new ScCellRangesObj( pDocShell, aMatchedRanges ));
 }
 }
 }
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 6 commits - sc/CppunitTest_sc_tablesheetobj.mk sc/CppunitTest_sc_tablesheetsobj.mk sc/qa sc/source test/inc test/Library_subsequenttest.mk test/Package_inc.mk test/source

2012-01-25 Thread Markus Mohrhard
 sc/CppunitTest_sc_tablesheetobj.mk |  140 +
 sc/CppunitTest_sc_tablesheetsobj.mk|   20 +--
 sc/qa/extras/scdatapilottableobj.cxx   |   16 ++
 sc/qa/extras/sctablesheetobj.cxx   |   87 +++
 sc/qa/extras/testdocuments/ScTableSheetObj.ods |binary
 sc/qa/unoapi/knownissues.xcl   |   13 ++
 sc/source/ui/unoobj/cellsuno.cxx   |4 
 test/Library_subsequenttest.mk |2 
 test/Package_inc.mk|2 
 test/inc/test/container/xnamed.hxx |   53 +
 test/inc/test/util/xsearchable.hxx |   55 +
 test/source/container/xnamed.cxx   |   58 ++
 test/source/util/xsearchable.cxx   |   79 ++
 13 files changed, 514 insertions(+), 15 deletions(-)

New commits:
commit 3e82bf0e5e6a1d5dcbe6b7ebbbe124912e8e8700
Author: Markus Mohrhard 
Date:   Wed Jan 25 21:01:06 2012 +0100

add test for ScTableSheetObj

diff --git a/sc/CppunitTest_sc_tablesheetobj.mk 
b/sc/CppunitTest_sc_tablesheetobj.mk
new file mode 100644
index 000..9ccd9c8
--- /dev/null
+++ b/sc/CppunitTest_sc_tablesheetobj.mk
@@ -0,0 +1,140 @@
+# -*- Mode: makefile-gmake; tab-width: 4; indent-tabs-mode: t -*-
+#*
+# Version: MPL 1.1 / GPLv3+ / LGPLv3+
+#
+# The contents of this file are subject to the Mozilla Public License Version
+# 1.1 (the "License"); you may not use this file except in compliance with
+# the License or as specified alternatively below. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS IS" basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+# for the specific language governing rights and limitations under the
+# License.
+#
+# The Initial Developer of the Original Code is
+#   Markus Mohrhard 
+# Portions created by the Initial Developer are Copyright (C) 2011 the
+# Initial Developer. All Rights Reserved.
+#
+# Major Contributor(s):
+#
+# For minor contributions see the git repository.
+#
+# Alternatively, the contents of this file may be used under the terms of
+# either the GNU General Public License Version 3 or later (the "GPLv3+"), or
+# the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
+# in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
+# instead of those above.
+#*
+
+$(eval $(call gb_CppunitTest_CppunitTest,sc_spreadsheetobj))
+
+$(eval $(call gb_CppunitTest_add_exception_objects,sc_spreadsheetobj, \
+sc/qa/extras/sctablesheetobj \
+))
+
+$(eval $(call gb_CppunitTest_add_linked_libs,sc_spreadsheetobj, \
+avmedia \
+basegfx \
+comphelper \
+cppu \
+cppuhelper \
+drawinglayer \
+editeng \
+fileacc \
+for \
+forui \
+i18nisolang1 \
+msfilter \
+oox \
+sal \
+salhelper \
+sax \
+sb \
+sc \
+sfx \
+sot \
+subsequenttest \
+svl \
+svt \
+svx \
+svxcore \
+   test \
+tl \
+tk \
+ucbhelper \
+   unotest \
+utl \
+vbahelper \
+vcl \
+xo \
+   $(gb_STDLIBS) \
+))
+
+$(eval $(call gb_CppunitTest_set_include,sc_spreadsheetobj,\
+-I$(realpath $(SRCDIR)/sc/source/ui/inc) \
+-I$(realpath $(SRCDIR)/sc/inc) \
+$$(INCLUDE) \
+-I$(OUTDIR)/inc \
+))
+
+$(eval $(call gb_CppunitTest_add_api,sc_spreadsheetobj,\
+offapi \
+udkapi \
+))
+
+$(eval $(call gb_CppunitTest_uses_ure,sc_spreadsheetobj))
+
+$(eval $(call gb_CppunitTest_add_type_rdbs,sc_spreadsheetobj,\
+types \
+))
+
+$(eval $(call gb_CppunitTest_add_components,sc_spreadsheetobj,\
+basic/util/sb \
+comphelper/util/comphelp \
+configmgr/source/configmgr \
+dbaccess/util/dba \
+fileaccess/source/fileacc \
+filter/source/config/cache/filterconfig1 \
+forms/util/frm \
+framework/util/fwk \
+i18npool/util/i18npool \
+i18npool/source/search/i18nsearch \
+oox/util/oox \
+package/source/xstor/xstor \
+package/util/package2 \
+sax/source/expatwrap/expwrap \
+sax/source/fastparser/fastsax \
+sc/util/sc \
+sc/util/scd \
+sc/util/scfilt \
+sc/util/vbaobj \
+scripting/source/basprov/basprov \
+scripting/util/scriptframe \
+sfx2/util/sfx \
+sot/util/sot \
+svl/source/fsstor/fsstorage \
+toolkit/util/tk \
+ucb/source/core/ucb1 \
+ucb/source/ucp/file/ucpfile1 \
+ucb/source/ucp/tdoc/ucptdoc1 \
+unotools/util/utl \
+unoxml/source/rdf/unordf \
+unoxml/source/service/unoxml \
+))
+
+$(eval $(call gb_CppunitTest_set_args,sc_spreadsheetobj,\
+--headless \
+--protector unoexceptionprotector$(gb_Library_DLLEXT) 
unoexceptionprotector \
+"-env:CONFIGURATION_LAYERS=xcsxcu:$(call 

[Libreoffice-commits] .: Branch 'libreoffice-3-4' - filter/source

2012-01-25 Thread Petr Mladek
 filter/source/msfilter/msdffimp.cxx |   20 +---
 1 file changed, 13 insertions(+), 7 deletions(-)

New commits:
commit 3475d300ef29866542007e295569075e592bde66
Author: Ivan Timofeev 
Date:   Wed Jan 25 20:54:27 2012 +0100

fdo#43193: fix rotation of shapes in imported MS documents

Signed-off-by: Petr Mladek 

diff --git a/filter/source/msfilter/msdffimp.cxx 
b/filter/source/msfilter/msdffimp.cxx
index 5764c66..784b5a0 100644
--- a/filter/source/msfilter/msdffimp.cxx
+++ b/filter/source/msfilter/msdffimp.cxx
@@ -4643,6 +4643,8 @@ SdrObject* SvxMSDffManager::ImportGroup( const 
DffRecordHeader& rHd, SvStream& r
 rSt >> aRecHd;
 if ( aRecHd.nRecType == DFF_msofbtSpContainer )
 {
+sal_Int32 nGroupRotateAngle = 0;
+sal_Int32 nSpFlags = 0;
 mnFix16Angle = 0;
 
 aRecHd.SeekToBegOfRecord(rSt);
@@ -4650,15 +4652,19 @@ SdrObject* SvxMSDffManager::ImportGroup( const 
DffRecordHeader& rHd, SvStream& r
 pRet = ImportObj( rSt, pClientData, rClientRect, rGlobalChildRect, 
nCalledByGroup + 1, pShapeId );
 if ( pRet )
 {
+nSpFlags = nGroupShapeFlags;
+nGroupRotateAngle = mnFix16Angle;
+
 Rectangle aClientRect( rClientRect );
+
 Rectangle aGlobalChildRect;
 if ( !nCalledByGroup || rGlobalChildRect.IsEmpty() )
 aGlobalChildRect = GetGlobalChildAnchor( rHd, rSt, aClientRect 
);
 else
 aGlobalChildRect = rGlobalChildRect;
 
-if ( ( mnFix16Angle > 4500 && mnFix16Angle <= 13500 )
-|| ( mnFix16Angle > 22500 && mnFix16Angle <= 31500 ) )
+if ( ( nGroupRotateAngle > 4500 && nGroupRotateAngle <= 13500 )
+|| ( nGroupRotateAngle > 22500 && nGroupRotateAngle <= 31500 ) 
)
 {
 sal_Int32 nHalfWidth = ( aClientRect.GetWidth() + 1 ) >> 1;
 sal_Int32 nHalfHeight = ( aClientRect.GetHeight() + 1 ) >> 1;
@@ -4704,18 +4710,18 @@ SdrObject* SvxMSDffManager::ImportGroup( const 
DffRecordHeader& rHd, SvStream& r
 aRecHd2.SeekToEndOfRecord( rSt );
 }
 
-if ( mnFix16Angle )
+if ( nGroupRotateAngle )
 {
-double a = mnFix16Angle * nPi180;
-pRet->NbcRotate( aClientRect.Center(), mnFix16Angle, sin( a ), 
cos( a ) );
+double a = nGroupRotateAngle * nPi180;
+pRet->NbcRotate( aClientRect.Center(), nGroupRotateAngle, sin( 
a ), cos( a ) );
 }
-if ( nGroupShapeFlags & SP_FFLIPV )// Vertical 
flip?
+if ( nSpFlags & SP_FFLIPV ) // Vertical flip?
 {  // BoundRect in aBoundRect
 Point aLeft( aClientRect.Left(), ( aClientRect.Top() + 
aClientRect.Bottom() ) >> 1 );
 Point aRight( aLeft.X() + 1000, aLeft.Y() );
 pRet->NbcMirror( aLeft, aRight );
 }
-if ( nGroupShapeFlags & SP_FFLIPH )// Horizontal 
flip?
+if ( nSpFlags & SP_FFLIPH ) // Horizontal flip?
 {  // BoundRect in aBoundRect
 Point aTop( ( aClientRect.Left() + aClientRect.Right() ) >> 1, 
aClientRect.Top() );
 Point aBottom( aTop.X(), aTop.Y() + 1000 );
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sal/osl

2012-01-25 Thread François Tigeot
 sal/osl/unx/system.c |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 5f32a5558e8672ed56d5d393228aefacc632846c
Author: François Tigeot 
Date:   Wed Jan 25 19:43:17 2012 +0100

NetBSD also needs the internal gethostbyname_r() implementation

Reported by: Thomas Klausner 

diff --git a/sal/osl/unx/system.c b/sal/osl/unx/system.c
index bf3e51e..720d1cd 100644
--- a/sal/osl/unx/system.c
+++ b/sal/osl/unx/system.c
@@ -33,7 +33,7 @@
 static pthread_mutex_t getrtl_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /* struct passwd differs on some platforms */
-#if defined(MACOSX) || defined(IOS) || defined(OPENBSD)
+#if defined(MACOSX) || defined(IOS) || defined(OPENBSD) || defined(NETBSD)
 
 extern int h_errno;
 
@@ -124,7 +124,7 @@ struct hostent *gethostbyname_r(const char *name, struct 
hostent *result,
 
   return res;
 }
-#endif // OSX || IOS || OPENBSD
+#endif // OSX || IOS || OPENBSD || NETBSD
 
 #if defined(MACOSX)
 /*
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sc/qa

2012-01-25 Thread Kohei Yoshida
 sc/qa/unit/ucalc.cxx |   31 ---
 1 file changed, 24 insertions(+), 7 deletions(-)

New commits:
commit e5dea1e1a5ca307c6b3b6becfb6486d57efae181
Author: Kohei Yoshida 
Date:   Wed Jan 25 13:26:50 2012 -0500

New unit test for refreshing a pivot table without data cache.

Also, FillOldParam() and GetMembers() removed since 1) they were not
necessary and 2) it would create a data cache in the process.

diff --git a/sc/qa/unit/ucalc.cxx b/sc/qa/unit/ucalc.cxx
index ec31a04..e83f500 100644
--- a/sc/qa/unit/ucalc.cxx
+++ b/sc/qa/unit/ucalc.cxx
@@ -1174,13 +1174,6 @@ ScDPObject* createDPFromSourceDesc(
 ScDPObject* pDPObj = new ScDPObject(pDoc);
 pDPObj->SetSheetDesc(rDesc);
 pDPObj->SetOutRange(ScAddress(0, 0, 1));
-ScPivotParam aParam;
-pDPObj->FillOldParam(aParam);
-for (size_t i = 0; i < nFieldCount; ++i)
-{
-vector aMembers;
-pDPObj->GetMembers(i, 0, aMembers);
-}
 
 ScDPSaveData aSaveData;
 // Set data pilot table output options.
@@ -1424,6 +1417,30 @@ void Test::testPivotTable()
 CPPUNIT_ASSERT_MESSAGE("There shouldn't be any more data cache.",
pDPs->GetSheetCaches().size() == 0);
 
+// Insert a brand new pivot table object once again, but this time, don't
+// create the output to avoid creating a data cache.
+m_pDoc->DeleteTab(1);
+m_pDoc->InsertTab(1, OUString(RTL_CONSTASCII_USTRINGPARAM("Table")));
+
+pDPObj = createDPFromRange(
+m_pDoc, ScRange(nCol1, nRow1, 0, nCol2, nRow2, 0), aFields, 
nFieldCount, false);
+bSuccess = pDPs->InsertNewTable(pDPObj);
+CPPUNIT_ASSERT_MESSAGE("failed to insert a new datapilot object into 
document", bSuccess);
+CPPUNIT_ASSERT_MESSAGE("there should be only one data pilot table.",
+   pDPs->GetCount() == 1);
+pDPObj->SetName(pDPs->CreateNewName());
+CPPUNIT_ASSERT_MESSAGE("Data cache shouldn't exist yet before creating the 
table output.",
+   pDPs->GetSheetCaches().size() == 0);
+
+// Now, "refresh" the table.  This should still return a reference to self
+// even with the absence of data cache.
+aRefs.clear();
+pDPs->ReloadCache(pDPObj, aRefs);
+CPPUNIT_ASSERT_MESSAGE("It should return the same object as a reference.",
+   aRefs.size() == 1 && *aRefs.begin() == pDPObj);
+
+pDPs->FreeTable(pDPObj);
+
 m_pDoc->DeleteTab(1);
 m_pDoc->DeleteTab(0);
 }
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - 3 commits - postprocess/prj sal/android sal/inc sal/Package_inc.mk solenv/inc svx/source sw/source vcl/android vcl/inc

2012-01-25 Thread Tor Lillqvist
 postprocess/prj/build.lst|2 
 sal/Package_inc.mk   |2 
 sal/android/android_native_app_glue.c|   15 -
 sal/android/lo-bootstrap.c   |7 
 sal/inc/osl/detail/android.h |  352 ---
 sal/inc/osl/detail/android_native_app_glue.h |  349 ++
 solenv/inc/unxandr/lo-bootstrap.h|2 
 svx/source/stbctrls/zoomsliderctrl.cxx   |4 
 sw/source/ui/uiview/viewport.cxx |4 
 vcl/android/androidinst.cxx  |   37 +-
 vcl/inc/android/androidinst.hxx  |1 
 11 files changed, 387 insertions(+), 388 deletions(-)

New commits:
commit 25f78344e8dea95cedb0b981f08865d676154e5b
Author: Tor Lillqvist 
Date:   Wed Jan 25 16:41:45 2012 +0200

Bin global_android_app and instead use lo-bootstrap API

Instead of introducing a global variable, use the already existing
saved android_app pointer in lo-bootstrap.c, and just add a function
to retrieve it from there. Store it in the AndroidSalInstance.

Reanme osl/detail/android.h back to android_native_app_glue.h, which
is the name of that file in NDK/sources. "android.h" sounded to me too
grand, as if it was some universal Android header. But if we do start
to modify the android_native_app_glue stuff heavily, then it indeed
makes sense to call it something else. Until then, revert also some
whitespace changes to android_native_app_glue.c for it to be as close
as possible to the "upstream" one in the NDK, for clarity.

diff --git a/sal/Package_inc.mk b/sal/Package_inc.mk
index d0520ef..e43de3e 100644
--- a/sal/Package_inc.mk
+++ b/sal/Package_inc.mk
@@ -64,7 +64,7 @@ $(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/thread.hxx,osl/thread.hxx))
 $(eval $(call gb_Package_add_file,sal_inc,inc/osl/time.h,osl/time.h))
 $(eval $(call gb_Package_add_file,sal_inc,inc/osl/util.h,osl/util.h))
 $(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/file.h,osl/detail/file.h))
-$(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/android.h,osl/detail/android.h))
+$(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/android_native_app_glue.h,osl/detail/android_native_app_glue.h))
 $(eval $(call 
gb_Package_add_file,sal_inc,inc/rtl/allocator.hxx,rtl/allocator.hxx))
 $(eval $(call gb_Package_add_file,sal_inc,inc/rtl/alloc.h,rtl/alloc.h))
 $(eval $(call gb_Package_add_file,sal_inc,inc/rtl/bootstrap.h,rtl/bootstrap.h))
diff --git a/sal/android/android_native_app_glue.c 
b/sal/android/android_native_app_glue.c
index efd7a4b..cf5d8e8 100644
--- a/sal/android/android_native_app_glue.c
+++ b/sal/android/android_native_app_glue.c
@@ -22,7 +22,7 @@
 #include 
 #include 
 
-#include "osl/detail/android.h"
+#include "osl/detail/android_native_app_glue.h"
 #include 
 
 #define LOGI(...) ((void)__android_log_print(ANDROID_LOG_INFO, "threaded_app", 
__VA_ARGS__))
@@ -236,14 +236,9 @@ static void* android_app_entry(void* param) {
 // 
 
 static struct android_app* android_app_create(ANativeActivity* activity,
-void* savedState, size_t savedStateSize)
-{
+void* savedState, size_t savedStateSize) {
 struct android_app* android_app = (struct 
android_app*)malloc(sizeof(struct android_app));
 memset(android_app, 0, sizeof(struct android_app));
-
-// get this across to VCL.
-global_android_app = android_app;
-
 android_app->activity = activity;
 
 pthread_mutex_init(&android_app->mutex, NULL);
@@ -419,13 +414,9 @@ static void onInputQueueDestroyed(ANativeActivity* 
activity, AInputQueue* queue)
 android_app_set_input((struct android_app*)activity->instance, NULL);
 }
 
-__attribute__ ((visibility("default"))) struct android_app *global_android_app 
= NULL;
-
 __attribute__ ((visibility("default"))) void 
ANativeActivity_onCreate(ANativeActivity* activity,
-void* savedState, size_t savedStateSize)
-{
+void* savedState, size_t savedStateSize) {
 LOGI("Creating: %p\n", activity);
-
 activity->callbacks->onDestroy = onDestroy;
 activity->callbacks->onStart = onStart;
 activity->callbacks->onResume = onResume;
diff --git a/sal/android/lo-bootstrap.c b/sal/android/lo-bootstrap.c
index bd90494..3cb8d3a 100644
--- a/sal/android/lo-bootstrap.c
+++ b/sal/android/lo-bootstrap.c
@@ -1470,6 +1470,13 @@ lo_get_javavm(void)
 }
 
 __attribute__ ((visibility("default")))
+struct android_app *
+lo_get_app(void)
+{
+return app;
+}
+
+__attribute__ ((visibility("default")))
 void
 android_main(struct android_app* state)
 {
diff --git a/sal/inc/osl/detail/android.h b/sal/inc/osl/detail/android.h
deleted file mode 100644
index beb5b1d..000
--- a/sal/inc/osl/detail/android.h
+++ /dev/null
@@ -1,352 +0,0 @@
-/*
- * Copyright (C) 2010 The Android Open Source Project
- *
- * Licensed under the Apache License, Version 2.0 (the "License

[Libreoffice-commits] .: set_soenv.in

2012-01-25 Thread François Tigeot
 set_soenv.in |3 +++
 1 file changed, 3 insertions(+)

New commits:
commit a79889083b25d69ae6b801ed8cee90b5dd9199c4
Author: François Tigeot 
Date:   Wed Jan 25 18:50:35 2012 +0100

Ensure Env.Host.sh always return a zero exit code

* On some NetBSD systems, the last unset command returns a
  non-zero exit code

* This made the make(1) processes terminate immediately in
  source-env-and-recurse, breaking the build.

Reported by: Thomas Klausner 

diff --git a/set_soenv.in b/set_soenv.in
index 53b388f..704378d 100755
--- a/set_soenv.in
+++ b/set_soenv.in
@@ -1102,6 +1102,9 @@ ToFile( "ENV_SCRIPT", "$outfile", "e" );
 #
 print OUT "export $exportvars$newline";
 print OUT "unset $unsetvars$newline";
+# unset may return a non-zero value and make the initial
+# make(1) processes terminate with an error
+print OUT "true $newline";
 
 #
 #---
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: basctl/source basic/source sc/source sw/source

2012-01-25 Thread Takeshi Abe
 basctl/source/dlged/managelang.cxx |3 +--
 basctl/source/dlged/propbrw.cxx|3 +--
 basic/source/classes/sbxmod.cxx|   11 ---
 basic/source/sbx/sbxbase.cxx   |3 +--
 sc/source/core/data/column.cxx |2 +-
 sc/source/core/data/documen3.cxx   |3 +--
 sc/source/core/data/table4.cxx |3 +--
 sw/source/core/text/itrform2.cxx   |3 +--
 sw/source/core/txtnode/atrfld.cxx  |3 +--
 sw/source/ui/docvw/edtwin.cxx  |8 ++--
 10 files changed, 14 insertions(+), 28 deletions(-)

New commits:
commit bb51e8e72be424f0fd92350006c536a97fd4b210
Author: Takeshi Abe 
Date:   Thu Jan 26 01:02:30 2012 +0900

Deleting a null pointer is safe

diff --git a/basctl/source/dlged/managelang.cxx 
b/basctl/source/dlged/managelang.cxx
index eb16d60..58fd948 100644
--- a/basctl/source/dlged/managelang.cxx
+++ b/basctl/source/dlged/managelang.cxx
@@ -197,8 +197,7 @@ void ManageLanguageDialog::ClearLanguageBox()
 for ( i = 0; i < nCount; ++i )
 {
 LanguageEntry* pEntry = (LanguageEntry*)( 
m_aLanguageLB.GetEntryData(i) );
-if ( pEntry )
-delete pEntry;
+delete pEntry;
 }
 m_aLanguageLB.Clear();
 }
diff --git a/basctl/source/dlged/propbrw.cxx b/basctl/source/dlged/propbrw.cxx
index 5ee9c28..4e1f90f 100644
--- a/basctl/source/dlged/propbrw.cxx
+++ b/basctl/source/dlged/propbrw.cxx
@@ -308,8 +308,7 @@ Sequence< Reference< XInterface > >
 // next element
 pCurrent = pGroupIterator && pGroupIterator->IsMore() ? 
pGroupIterator->Next() : NULL;
 }
-if (pGroupIterator)
-delete pGroupIterator;
+delete pGroupIterator;
 }
 
 sal_Int32 nCount = aInterfaces.size();
diff --git a/basic/source/classes/sbxmod.cxx b/basic/source/classes/sbxmod.cxx
index d61b63c..40ae0d7 100644
--- a/basic/source/classes/sbxmod.cxx
+++ b/basic/source/classes/sbxmod.cxx
@@ -541,13 +541,10 @@ SbModule::SbModule( const String& rName,  sal_Bool 
bVBACompat )
 SbModule::~SbModule()
 {
 OSL_TRACE("Module named %s is destructing", rtl::OUStringToOString( 
GetName(), RTL_TEXTENCODING_UTF8 ).getStr() );
-if( pImage )
-delete pImage;
-if( pBreaks )
-delete pBreaks;
-if( pClassData )
-delete pClassData;
-mxWrapper = NULL;
+delete pImage;
+delete pBreaks;
+delete pClassData;
+mxWrapper = NULL;
 }
 
 uno::Reference< script::XInvocation >
diff --git a/basic/source/sbx/sbxbase.cxx b/basic/source/sbx/sbxbase.cxx
index 303f382..e2987d0 100644
--- a/basic/source/sbx/sbxbase.cxx
+++ b/basic/source/sbx/sbxbase.cxx
@@ -55,8 +55,7 @@ SbxAppData& GetSbxData_Impl()
 
 SbxAppData::~SbxAppData()
 {
-if( pBasicFormater )
-delete pBasicFormater;
+delete pBasicFormater;
 }
 
 
diff --git a/sc/source/core/data/column.cxx b/sc/source/core/data/column.cxx
index 6c1c849..50f0e95 100644
--- a/sc/source/core/data/column.cxx
+++ b/sc/source/core/data/column.cxx
@@ -93,7 +93,7 @@ ScColumn::ScColumn() :
 ScColumn::~ScColumn()
 {
 FreeAll();
-if (pAttrArray) delete pAttrArray;
+delete pAttrArray;
 }
 
 
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index 66973de..991eb6b 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -273,8 +273,7 @@ void ScDocument::SetDBCollection( ScDBCollection* 
pNewDBCollection, bool bRemove
 }
 }
 
-if (pDBCollection)
-delete pDBCollection;
+delete pDBCollection;
 
 pDBCollection = pNewDBCollection;
 }
diff --git a/sc/source/core/data/table4.cxx b/sc/source/core/data/table4.cxx
index bc99c5c..dac4111 100644
--- a/sc/source/core/data/table4.cxx
+++ b/sc/source/core/data/table4.cxx
@@ -564,8 +564,7 @@ void ScTable::FillAuto( SCCOL nCol1, SCROW nRow1, SCCOL 
nCol2, SCROW nRow2,
 {
 if ( bGetPattern )
 {
-if ( pNewPattern )
-delete pNewPattern;
+delete pNewPattern;
 if (bVertical)  // rInner&:=nRow, rOuter&:=nCol
 pSrcPattern = 
aCol[nCol].GetPattern(static_cast(nAtSrc));
 else// rInner&:=nCol, rOuter&:=nRow
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 54a7825..b46d5b8 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1629,8 +1629,7 @@ xub_StrLen SwTxtFormatter::FormatLine( const xub_StrLen 
nStartPos )
 GetInfo().GetParaPortion()->GetReformat()->LeftMove( GetInfo().GetIdx() );
 
 // delete master copy of rest portion
-if ( pSaveFld )
-delete pSaveFld;
+delete pSaveFld;
 
 xub_StrLen nNewStart = nStartPos + pCurr->GetLen();
 
diff --git a/sw/source/core/txtnode/atrfld.cxx 
b/sw/source/core/txtnode/atrfld.cxx
index 4789c5f..dc285ef 100644
--- a/sw/source/core/txtnode/atrfld.cxx
+++ b/sw/source/core/txtnode/atrfld.cxx
@@ -134,8 +134,7 @@ void SwFmtFld::Reg

[Libreoffice-commits] .: sc/qa

2012-01-25 Thread Kohei Yoshida
 sc/qa/unit/ucalc.cxx |   96 +--
 1 file changed, 94 insertions(+), 2 deletions(-)

New commits:
commit 85d34beec5f8196896487c96028b2dc2ce3cf6c8
Author: Kohei Yoshida 
Date:   Wed Jan 25 12:50:54 2012 -0500

New unit test for pivot table's date output handling.

We rely on the cell type of those date value outputs when grouping
by date or value range.

diff --git a/sc/qa/unit/ucalc.cxx b/sc/qa/unit/ucalc.cxx
index 7f5f143..ec31a04 100644
--- a/sc/qa/unit/ucalc.cxx
+++ b/sc/qa/unit/ucalc.cxx
@@ -130,6 +130,13 @@ public:
 void testPivotTableLabels();
 
 /**
+ * Make sure that we set cells displaying date values numeric cells,
+ * rather than text cells.  Grouping by date or number functionality
+ * depends on this.
+ */
+void testPivotTableDateLabels();
+
+/**
  * Test for pivot table's filtering functionality by page fields.
  */
 void testPivotTableFilters();
@@ -190,6 +197,7 @@ public:
 CPPUNIT_TEST(testMatrix);
 CPPUNIT_TEST(testPivotTable);
 CPPUNIT_TEST(testPivotTableLabels);
+CPPUNIT_TEST(testPivotTableDateLabels);
 CPPUNIT_TEST(testPivotTableFilters);
 CPPUNIT_TEST(testPivotTableNamedSource);
 CPPUNIT_TEST(testSheetCopy);
@@ -1144,13 +1152,13 @@ bool checkDPTableOutput(ScDocument* pDoc, const 
ScRange& aOutRange, const char*
 bool bEqual = aCheckVal.equals(aVal);
 if (!bEqual)
 {
-cerr << "Expected: " << aCheckVal << "  Actual: " << aVal 
<< endl;
+cout << "Expected: " << aCheckVal << "  Actual: " << aVal 
<< endl;
 bResult = false;
 }
 }
 else if (!aVal.isEmpty())
 {
-cerr << "Empty cell expected" << endl;
+cout << "Empty cell expected" << endl;
 bResult = false;
 }
 }
@@ -1476,6 +1484,90 @@ void Test::testPivotTableLabels()
 CPPUNIT_ASSERT_MESSAGE("Table output check failed", bSuccess);
 }
 
+pDPs->FreeTable(pDPObj);
+
+m_pDoc->DeleteTab(1);
+m_pDoc->DeleteTab(0);
+}
+
+void Test::testPivotTableDateLabels()
+{
+m_pDoc->InsertTab(0, OUString(RTL_CONSTASCII_USTRINGPARAM("Data")));
+m_pDoc->InsertTab(1, OUString(RTL_CONSTASCII_USTRINGPARAM("Table")));
+
+// Dimension definition
+DPFieldDef aFields[] = {
+{ "Name",  sheet::DataPilotFieldOrientation_ROW },
+{ "Date",  sheet::DataPilotFieldOrientation_COLUMN },
+{ "Value", sheet::DataPilotFieldOrientation_DATA }
+};
+
+// Raw data
+const char* aData[][3] = {
+{ "Zena",   "2011-1-1", "30" },
+{ "Yodel",  "2011-1-2", "20" },
+{ "Xavior", "2011-1-3", "45" }
+};
+
+size_t nFieldCount = SAL_N_ELEMENTS(aFields);
+size_t nDataCount = SAL_N_ELEMENTS(aData);
+
+ScRange aSrcRange = insertDPSourceData(m_pDoc, aFields, nFieldCount, 
aData, nDataCount);
+SCROW nRow1 = aSrcRange.aStart.Row(), nRow2 = aSrcRange.aEnd.Row();
+SCCOL nCol1 = aSrcRange.aStart.Col(), nCol2 = aSrcRange.aEnd.Col();
+
+ScDPObject* pDPObj = createDPFromRange(
+m_pDoc, ScRange(nCol1, nRow1, 0, nCol2, nRow2, 0), aFields, 
nFieldCount, false);
+
+ScDPCollection* pDPs = m_pDoc->GetDPCollection();
+bool bSuccess = pDPs->InsertNewTable(pDPObj);
+CPPUNIT_ASSERT_MESSAGE("failed to insert a new datapilot object into 
document", bSuccess);
+CPPUNIT_ASSERT_MESSAGE("there should be only one data pilot table.",
+   pDPs->GetCount() == 1);
+pDPObj->SetName(pDPs->CreateNewName());
+
+bool bOverFlow = false;
+ScRange aOutRange = pDPObj->GetNewOutputRange(bOverFlow);
+CPPUNIT_ASSERT_MESSAGE("Table overflow!?", !bOverFlow);
+
+pDPObj->Output(aOutRange.aStart);
+aOutRange = pDPObj->GetOutRange();
+
+{
+// Expected output table content.  0 = empty cell
+const char* aOutputCheck[][5] = {
+{ "Sum - Value", "Date", 0, 0, 0 },
+{ "Name", "2011-01-01", "2011-01-02", "2011-01-03", "Total Result" 
},
+{ "Xavior",  0, 0, "45", "45" },
+{ "Yodel",  0, "20", 0, "20" },
+{ "Zena",  "30", 0, 0, "30" },
+{ "Total Result", "30", "20", "45", "95" }
+};
+
+bSuccess = checkDPTableOutput<5>(m_pDoc, aOutRange, aOutputCheck, 
"DataPilot table output");
+CPPUNIT_ASSERT_MESSAGE("Table output check failed", bSuccess);
+}
+
+{
+const char* aChecks[] = {
+"2011-01-01", "2011-01-02", "2011-01-03"
+};
+
+// Make sure those cells that contain dates are numeric.
+SCROW nRow = aOutRange.aStart.Row() + 1;
+nCol1 = aOutRange.aStart.Col() + 1;
+nCol2 = nCol1 + 2;
+for (SCCOL nCol = nCol1; nCol <= nCol2; ++nCol)
+{
+OUString aVal = m_pDoc->GetString(nCol, nRow, 1);
+CPPUNIT_A

[Libreoffice-commits] .: 3 commits - basctl/source cui/source dbaccess/source offapi/com officecfg/registry sw/source unotools/inc unotools/Library_utl.mk unotools/Package_inc.mk unotools/source

2012-01-25 Thread Stephan Bergmann
 basctl/source/basicide/baside2.hxx   |   24 -
 basctl/source/basicide/baside2b.cxx  |  108 +---
 cui/source/options/fontsubs.cxx  |   42 ++-
 cui/source/options/fontsubs.hxx  |7 
 dbaccess/source/ui/control/sqledit.cxx   |   86 +-
 dbaccess/source/ui/inc/sqledit.hxx   |   17 +
 offapi/com/sun/star/configuration/ReadOnlyAccess.idl |2 
 officecfg/registry/cppheader.xsl |   24 +
 sw/source/ui/docvw/srcedtw.cxx   |   84 +-
 sw/source/ui/inc/srcedtw.hxx |   23 +
 unotools/Library_utl.mk  |1 
 unotools/Package_inc.mk  |1 
 unotools/inc/unotools/configuration.hxx  |   48 +++
 unotools/inc/unotools/itemholderbase.hxx |1 
 unotools/inc/unotools/sourceviewconfig.hxx   |   62 
 unotools/source/config/configuration.cxx |   25 +
 unotools/source/config/itemholder1.cxx   |5 
 unotools/source/config/sourceviewconfig.cxx  |  242 ---
 18 files changed, 384 insertions(+), 418 deletions(-)

New commits:
commit a2195b2dc301a6c2cfd0bf1a7ff74483bcc5998a
Author: Stephan Bergmann 
Date:   Wed Jan 25 18:18:18 2012 +0100

Replace SourceViewConfig with (simplified) direct configuration access.

diff --git a/basctl/source/basicide/baside2.hxx 
b/basctl/source/basicide/baside2.hxx
index 8d5aab9..a44e02b 100644
--- a/basctl/source/basicide/baside2.hxx
+++ b/basctl/source/basicide/baside2.hxx
@@ -50,6 +50,7 @@ class SvxSearchItem;
 
 #include 
 #include 
+#include 
 
 #include "breakpoint.hxx"
 #include "linenumberwindow.hxx"
@@ -58,10 +59,9 @@ DBG_NAMEEX( ModulWindow )
 
 #define MARKER_NOMARKER 0x
 
-namespace utl
-{
-class SourceViewConfig;
-}
+namespace com { namespace sun { namespace star { namespace beans {
+class XMultiPropertySet;
+} } } }
 
 // #108672 Helper functions to get/set text in TextEngine
 // using the stream interface (get/setText() only supports
@@ -91,18 +91,19 @@ inline void ProgressInfo::StepProgress()
 SetState( ++nCurState );
 }
 
-
-namespace svt {
-class SourceViewConfig;
-}
-
-class EditorWindow : public Window, public SfxListener, public 
utl::ConfigurationListener
+class EditorWindow : public Window, public SfxListener
 {
 private:
+class ChangesListener;
+friend class ChangesListener;
+
 ExtTextView*pEditView;
 ExtTextEngine*  pEditEngine;
 
-utl::SourceViewConfig* pSourceViewConfig;
+rtl::Reference< ChangesListener > listener_;
+osl::Mutex mutex_;
+com::sun::star::uno::Reference< com::sun::star::beans::XMultiPropertySet >
+notifier_;
 
 longnCurTextWidth;
 
@@ -139,7 +140,6 @@ protected:
 virtual voidCommand( const CommandEvent& rCEvt );
 virtual voidLoseFocus();
 virtual voidRequestHelp( const HelpEvent& rHEvt );
-virtual voidConfigurationChanged( utl::ConfigurationBroadcaster*, 
sal_uInt32 );
 
 voidDoSyntaxHighlight( sal_uLong nPara );
 String  GetWordAtCursor();
diff --git a/basctl/source/basicide/baside2b.cxx 
b/basctl/source/basicide/baside2b.cxx
index 52f9752..101fcfd 100644
--- a/basctl/source/basicide/baside2b.cxx
+++ b/basctl/source/basicide/baside2b.cxx
@@ -40,8 +40,11 @@
 #include 
 #include 
 #include 
+#include 
+#include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -52,7 +55,6 @@
 #include 
 #include 
 #include 
-#include 
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -147,6 +149,30 @@ void lcl_SeparateNameAndIndex( const String& rVName, 
String& rVar, String& rInde
 }
 }
 
+class EditorWindow::ChangesListener:
+public cppu::WeakImplHelper1< beans::XPropertiesChangeListener >
+{
+public:
+ChangesListener(EditorWindow & editor): editor_(editor) {}
+
+private:
+virtual ~ChangesListener() {}
+
+virtual void disposing(lang::EventObject const &) throw (RuntimeException)
+{
+osl::MutexGuard g(editor_.mutex_);
+editor_.notifier_.clear();
+}
+
+virtual void propertiesChange(
+Sequence< beans::PropertyChangeEvent > const &) throw 
(RuntimeException)
+{
+SolarMutexGuard g;
+editor_.ImplSetFont();
+}
+
+EditorWindow & editor_;
+};
 
 EditorWindow::EditorWindow( Window* pParent ) :
 Window( pParent, WB_BORDER )
@@ -156,7 +182,6 @@ EditorWindow::EditorWindow( Window* pParent ) :
 pModulWindow = 0;
 pEditView = 0;
 pEditEngine = 0;
-pSourceViewConfig = new utl::SourceViewConfig;
 bHighlightning = sal_False;
 pProgress = 0;
 nCurTextWidth = 0;
@@ -165,15 +190,35 @@ EditorWindow::EditorWindow( Window* pParent ) :
 SetPointer( Pointer( POINTER_TEXT ) );
 
 SetHelpId( HID_BASICIDE_EDITORWINDOW );
-pSourceViewConfig->AddListener(this);
+
+// Using "

[Libreoffice-commits] .: Branch 'feature/android' - vcl/android

2012-01-25 Thread Michael Meeks
 vcl/android/androidinst.cxx |  157 +++-
 1 file changed, 155 insertions(+), 2 deletions(-)

New commits:
commit 5c59f1e22aaf9e495e3c0d207660cc36d3c2ac82
Author: Michael Meeks 
Date:   Wed Jan 25 17:13:04 2012 +

android: more vcl pieces, wake/yield/loop bits and test pattern

diff --git a/vcl/android/androidinst.cxx b/vcl/android/androidinst.cxx
index 08c01ae..aba4b0b 100644
--- a/vcl/android/androidinst.cxx
+++ b/vcl/android/androidinst.cxx
@@ -30,8 +30,140 @@
 #include 
 #include 
 #include 
+#include 
 #include 
+#include 
 #include 
+#include 
+
+static rtl::OString MotionEdgeFlagsToString(int32_t nFlags)
+{
+rtl::OStringBuffer aStr;
+if (nFlags == AMOTION_EVENT_EDGE_FLAG_NONE)
+aStr.append ("no-edge");
+if (nFlags & AMOTION_EVENT_EDGE_FLAG_TOP)
+aStr.append (":top");
+if (nFlags & AMOTION_EVENT_EDGE_FLAG_BOTTOM)
+aStr.append (":bottom");
+if (nFlags & AMOTION_EVENT_EDGE_FLAG_LEFT)
+aStr.append (":left");
+if (nFlags & AMOTION_EVENT_EDGE_FLAG_RIGHT)
+aStr.append (":right");
+return aStr.makeStringAndClear();
+}
+
+static rtl::OString KeyMetaStateToString(int32_t nFlags)
+{
+rtl::OStringBuffer aStr;
+if (nFlags == AMETA_NONE)
+aStr.append ("no-meta");
+if (nFlags & AMETA_ALT_ON)
+aStr.append (":alt");
+if (nFlags & AMETA_SHIFT_ON)
+aStr.append (":shift");
+if (nFlags & AMETA_SYM_ON)
+aStr.append (":sym");
+return aStr.makeStringAndClear();
+}
+
+int32_t AMotionEvent_getEdgeFlags(const AInputEvent* motion_event);
+
+extern "C" {
+void onAppCmd_cb (struct android_app* app, int32_t cmd)
+{
+fprintf (stderr, "app cmd for app %p, cmd %d\n", app, cmd);
+ANativeWindow *pWindow = global_android_app->window;
+switch (cmd) {
+case APP_CMD_INIT_WINDOW:
+{
+ARect aRect = { 0, 0, 0, 0 };
+aRect.right = ANativeWindow_getWidth(pWindow);
+aRect.bottom = ANativeWindow_getHeight(pWindow);
+fprintf (stderr, "we have an app window ! %p %dx%x (%d)\n",
+ pWindow, aRect.right, aRect.bottom,
+ ANativeWindow_getFormat(pWindow));
+ANativeWindow_Buffer aBuffer;
+memset ((void *)&aBuffer, 0, sizeof (aBuffer));
+int32_t nRet = ANativeWindow_lock(pWindow, &aBuffer, &aRect);
+fprintf (stderr, "locked window %d returned rect: %d,%d->%d,%d "
+ "buffer: %dx%d stride %d, format %d, bits %p\n",
+ nRet, aRect.left, aRect.top, aRect.right, aRect.bottom,
+ aBuffer.width, aBuffer.height, aBuffer.stride,
+ aBuffer.format, aBuffer.bits);
+if (aBuffer.bits)
+{
+// hard-code / guess at a format ...
+int32_t *p = (int32_t *)aBuffer.bits;
+for (int32_t y = 0; y < aBuffer.height; y++)
+{
+for (int32_t x = 0; x < aBuffer.stride / 4; x++)
+*p++ = (y << 24) + x;
+}
+}
+ANativeWindow_unlockAndPost(pWindow);
+fprintf (stderr, "done render!\n");
+break;
+}
+case APP_CMD_WINDOW_RESIZED:
+{
+ARect aRect = { 0, 0, 0, 0 };
+aRect.right = ANativeWindow_getWidth(pWindow);
+aRect.bottom = ANativeWindow_getHeight(pWindow);
+fprintf (stderr, "app window resized to ! %p %dx%x (%d)\n",
+ pWindow, aRect.right, aRect.bottom,
+ ANativeWindow_getFormat(pWindow));
+break;
+}
+
+case APP_CMD_CONTENT_RECT_CHANGED:
+{
+ARect aRect = global_android_app->contentRect;
+fprintf (stderr, "content rect changed [ k/b popped up etc. ] 
%d,%d->%d,%d\n",
+ aRect.left, aRect.top, aRect.right, aRect.bottom);
+break;
+}
+default:
+fprintf (stderr, "unhandled app cmd %d\n", cmd);
+break;
+}
+}
+
+int32_t onInputEvent_cb (struct android_app* app, AInputEvent* event)
+{
+fprintf (stderr, "input event for app %p, event %p type %d source %d 
device id %d\n",
+ app, event,
+ AInputEvent_getType(event),
+ AInputEvent_getSource(event),
+ AInputEvent_getDeviceId(event));
+
+switch (AInputEvent_getType(event))
+{
+case AINPUT_EVENT_TYPE_KEY:
+{
+int32_t nAction = AKeyEvent_getAction(event);
+fprintf (stderr, "key event keycode %d '%s' %s\n",
+ AKeyEvent_getKeyCode(event),
+ nAction == AKEY_EVENT_ACTION_DOWN ? "down" :
+ nAction == AKEY_EVENT_ACTION_UP ? "up" : "multiple",
+ 
KeyMetaStateToString(AKeyEvent_getMeta

[Libreoffice-commits] .: 3 commits - postprocess/prj sal/android sal/inc sal/Package_inc.mk solenv/inc svx/source sw/source vcl/android vcl/inc

2012-01-25 Thread Tor Lillqvist
 postprocess/prj/build.lst|2 
 sal/Package_inc.mk   |2 
 sal/android/android_native_app_glue.c|   15 -
 sal/android/lo-bootstrap.c   |7 
 sal/inc/osl/detail/android.h |  352 ---
 sal/inc/osl/detail/android_native_app_glue.h |  349 ++
 solenv/inc/unxandr/lo-bootstrap.h|2 
 svx/source/stbctrls/zoomsliderctrl.cxx   |4 
 sw/source/ui/uiview/viewport.cxx |4 
 vcl/android/androidinst.cxx  |   14 -
 vcl/inc/android/androidinst.hxx  |1 
 11 files changed, 376 insertions(+), 376 deletions(-)

New commits:
commit f9c0e552355a0ae30ba75b427a3d8749ca8ebe9b
Author: Tor Lillqvist 
Date:   Wed Jan 25 16:41:45 2012 +0200

Bin global_android_app and instead use lo-bootstrap API

Instead of introducing a global variable, use the already existing
saved android_app pointer in lo-bootstrap.c, and just add a function
to rettrieve that.

Reanme osl/detail/android.h back to android_native_app_glue.h, which
is the file from NDK/sources that it is. "android.h" sounded to me too
grand, as if it was some universal Android header. But if we do start
to modify the android_native_app_glue stuff heavily, then it indeed
makes sense to call it something else. Until then, revert also some
whitespace changes to android_native_app_glue.c for it to be as close
as possible to the "upstream" one in the NDK, for clarity.

diff --git a/sal/Package_inc.mk b/sal/Package_inc.mk
index d0520ef..e43de3e 100644
--- a/sal/Package_inc.mk
+++ b/sal/Package_inc.mk
@@ -64,7 +64,7 @@ $(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/thread.hxx,osl/thread.hxx))
 $(eval $(call gb_Package_add_file,sal_inc,inc/osl/time.h,osl/time.h))
 $(eval $(call gb_Package_add_file,sal_inc,inc/osl/util.h,osl/util.h))
 $(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/file.h,osl/detail/file.h))
-$(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/android.h,osl/detail/android.h))
+$(eval $(call 
gb_Package_add_file,sal_inc,inc/osl/detail/android_native_app_glue.h,osl/detail/android_native_app_glue.h))
 $(eval $(call 
gb_Package_add_file,sal_inc,inc/rtl/allocator.hxx,rtl/allocator.hxx))
 $(eval $(call gb_Package_add_file,sal_inc,inc/rtl/alloc.h,rtl/alloc.h))
 $(eval $(call gb_Package_add_file,sal_inc,inc/rtl/bootstrap.h,rtl/bootstrap.h))
diff --git a/sal/android/android_native_app_glue.c 
b/sal/android/android_native_app_glue.c
index efd7a4b..cf5d8e8 100644
--- a/sal/android/android_native_app_glue.c
+++ b/sal/android/android_native_app_glue.c
@@ -22,7 +22,7 @@
 #include 
 #include 
 
-#include "osl/detail/android.h"
+#include "osl/detail/android_native_app_glue.h"
 #include 
 
 #define LOGI(...) ((void)__android_log_print(ANDROID_LOG_INFO, "threaded_app", 
__VA_ARGS__))
@@ -236,14 +236,9 @@ static void* android_app_entry(void* param) {
 // 
 
 static struct android_app* android_app_create(ANativeActivity* activity,
-void* savedState, size_t savedStateSize)
-{
+void* savedState, size_t savedStateSize) {
 struct android_app* android_app = (struct 
android_app*)malloc(sizeof(struct android_app));
 memset(android_app, 0, sizeof(struct android_app));
-
-// get this across to VCL.
-global_android_app = android_app;
-
 android_app->activity = activity;
 
 pthread_mutex_init(&android_app->mutex, NULL);
@@ -419,13 +414,9 @@ static void onInputQueueDestroyed(ANativeActivity* 
activity, AInputQueue* queue)
 android_app_set_input((struct android_app*)activity->instance, NULL);
 }
 
-__attribute__ ((visibility("default"))) struct android_app *global_android_app 
= NULL;
-
 __attribute__ ((visibility("default"))) void 
ANativeActivity_onCreate(ANativeActivity* activity,
-void* savedState, size_t savedStateSize)
-{
+void* savedState, size_t savedStateSize) {
 LOGI("Creating: %p\n", activity);
-
 activity->callbacks->onDestroy = onDestroy;
 activity->callbacks->onStart = onStart;
 activity->callbacks->onResume = onResume;
diff --git a/sal/android/lo-bootstrap.c b/sal/android/lo-bootstrap.c
index bd90494..3cb8d3a 100644
--- a/sal/android/lo-bootstrap.c
+++ b/sal/android/lo-bootstrap.c
@@ -1470,6 +1470,13 @@ lo_get_javavm(void)
 }
 
 __attribute__ ((visibility("default")))
+struct android_app *
+lo_get_app(void)
+{
+return app;
+}
+
+__attribute__ ((visibility("default")))
 void
 android_main(struct android_app* state)
 {
diff --git a/sal/inc/osl/detail/android.h b/sal/inc/osl/detail/android.h
deleted file mode 100644
index beb5b1d..000
--- a/sal/inc/osl/detail/android.h
+++ /dev/null
@@ -1,352 +0,0 @@
-/*
- * Copyright (C) 2010 The Android Open Source Project
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in c

[Libreoffice-commits] .: Branch 'libreoffice-3-5' - sc/source

2012-01-25 Thread Petr Mladek
 sc/source/core/data/dpoutput.cxx |   14 +++---
 1 file changed, 11 insertions(+), 3 deletions(-)

New commits:
commit 6cc0bf1394ef9d6941d38a55a6155688a6f9bd43
Author: Kohei Yoshida 
Date:   Tue Jan 24 16:32:10 2012 -0500

fdo#45067: Differentiate numeric and non-numeric field member values.

Signed-off-by: Petr Mladek 

diff --git a/sc/source/core/data/dpoutput.cxx b/sc/source/core/data/dpoutput.cxx
index 990e212..32179e3 100644
--- a/sc/source/core/data/dpoutput.cxx
+++ b/sc/source/core/data/dpoutput.cxx
@@ -795,10 +795,18 @@ void ScDPOutput::HeaderCell( SCCOL nCol, SCROW nRow, 
SCTAB nTab,
 
 if ( nFlags & sheet::MemberResultFlags::HASMEMBER )
 {
-// Avoid unwanted automatic format detection.
+bool bNumeric = (nFlags & sheet::MemberResultFlags::NUMERIC) != 0;
 ScSetStringParam aParam;
-aParam.mbDetectNumberFormat = false;
-aParam.mbSetTextCellFormat = true;
+if (bNumeric)
+{
+aParam.mbDetectNumberFormat = true;
+aParam.mbSetTextCellFormat = false;
+}
+else
+{
+aParam.mbDetectNumberFormat = false;
+aParam.mbSetTextCellFormat = true;
+}
 pDoc->SetString(nCol, nRow, nTab, rData.Caption, &aParam);
 }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: binfilter/bf_svtools

2012-01-25 Thread Caolán McNamara
 binfilter/bf_svtools/source/misc/svt_ehdl.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 58f9f554d5fb9a3ca9a2b80038cdfa9d609a72d7
Author: Caolán McNamara 
Date:   Tue Jan 24 20:57:51 2012 +

String(String

diff --git a/binfilter/bf_svtools/source/misc/svt_ehdl.cxx 
b/binfilter/bf_svtools/source/misc/svt_ehdl.cxx
index 4db63b8..5b14396 100644
--- a/binfilter/bf_svtools/source/misc/svt_ehdl.cxx
+++ b/binfilter/bf_svtools/source/misc/svt_ehdl.cxx
@@ -365,7 +365,7 @@ BOOL SfxErrorHandler::GetErrorString(
 SolarMutexGuard aGuard;
 
 BOOL bRet = FALSE;
-rStr=String(String(RTL_CONSTASCII_USTRINGPARAM("$(CLASS)$(ERROR)")));
+rStr=rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("$(CLASS)$(ERROR)"));
 ResId *pResId = new ResId(nId, *pMgr);
 
 {
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sw/source

2012-01-25 Thread Miklos Vajna
 sw/source/filter/rtf/swparrtf.cxx |6 ++
 1 file changed, 6 insertions(+)

New commits:
commit bb147bbb801b53dba8928340df7e2aa2d4545349
Author: Miklos Vajna 
Date:   Wed Jan 25 16:33:25 2012 +0100

fdo#43869 use the old rtf importer for paste

diff --git a/sw/source/filter/rtf/swparrtf.cxx 
b/sw/source/filter/rtf/swparrtf.cxx
index 8099617..81abb16 100644
--- a/sw/source/filter/rtf/swparrtf.cxx
+++ b/sw/source/filter/rtf/swparrtf.cxx
@@ -34,6 +34,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -161,6 +162,11 @@ sal_uLong SwRTFReader::Read( SwDoc &rDoc, const String& 
/*rBaseURL*/, SwPaM& /*r
 
 extern "C" SAL_DLLPUBLIC_EXPORT Reader* SAL_CALL ImportRTF()
 {
+// Use the old rtf importer by default for paste, till the new one supports
+// undo stack and PaM.
+SvtMiscOptions aMiscOptions;
+if (!aMiscOptions.IsExperimentalMode())
+return new RtfReader();
 return new SwRTFReader();
 }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - sal/osl

2012-01-25 Thread Michael Meeks
 sal/osl/unx/security.c |   20 +++-
 1 file changed, 11 insertions(+), 9 deletions(-)

New commits:
commit fd268507704ba82af2abe4f5f777daf4c43d74fe
Author: Michael Meeks 
Date:   Wed Jan 25 15:09:55 2012 +

android: cleanup osl security code for empty home / username fields

diff --git a/sal/osl/unx/security.c b/sal/osl/unx/security.c
index d73111c..96605fc 100644
--- a/sal/osl/unx/security.c
+++ b/sal/osl/unx/security.c
@@ -276,7 +276,7 @@ static sal_Bool SAL_CALL osl_psz_getUserName(oslSecurity 
Security, sal_Char* psz
 {
 oslSecurityImpl *pSecImpl = (oslSecurityImpl *)Security;
 
-if (pSecImpl == NULL)
+if (pSecImpl == NULL || pSecImpl->m_pPasswd.pw_name == NULL)
 return sal_False;
 
 strncpy(pszName, pSecImpl->m_pPasswd.pw_name, nMax);
@@ -364,14 +364,17 @@ static sal_Bool SAL_CALL osl_psz_getHomeDir(oslSecurity 
Security, sal_Char* pszD
 pStr = getenv("HOME");
 #endif
 
-if ((pStr != NULL) && (strlen(pStr) > 0) &&
-(access(pStr, 0) == 0))
+if (pStr != NULL && strlen(pStr) > 0 && access(pStr, 0) == 0)
 strncpy(pszDirectory, pStr, nMax);
-else
+else if (pSecImpl->m_pPasswd.pw_dir != NULL)
 strncpy(pszDirectory, pSecImpl->m_pPasswd.pw_dir, nMax);
+else
+return sal_False;
 }
-else
+else if (pSecImpl->m_pPasswd.pw_dir != NULL)
 strncpy(pszDirectory, pSecImpl->m_pPasswd.pw_dir, nMax);
+else
+return sal_False;
 
 return sal_True;
 }
@@ -403,8 +406,7 @@ static sal_Bool SAL_CALL osl_psz_getConfigDir(oslSecurity 
Security, sal_Char* ps
 {
 sal_Char *pStr = getenv("XDG_CONFIG_HOME");
 
-if ((pStr == NULL) || (strlen(pStr) == 0) ||
-(access(pStr, 0) != 0))
+if (pStr == NULL || strlen(pStr) == 0 || access(pStr, 0) != 0)
 {
 size_t n = 0;
 // a default equal to $HOME/.config should be used.
@@ -460,9 +462,9 @@ sal_Bool SAL_CALL osl_isAdministrator(oslSecurity Security)
 return sal_False;
 
 if (pSecImpl->m_pPasswd.pw_uid != 0)
-return (sal_False);
+return sal_False;
 
-return (sal_True);
+return sal_True;
 }
 
 void SAL_CALL osl_freeSecurityHandle(oslSecurity Security)
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/android' - android/qa

2012-01-25 Thread Michael Meeks
 android/qa/desktop/Makefile |   17 +
 1 file changed, 17 insertions(+)

New commits:
commit 3e52b896843ae0a9e137d4728e2ef73245e7e144
Author: Michael Meeks 
Date:   Wed Jan 25 14:45:16 2012 +

android: add versionrc generation for desktop

diff --git a/android/qa/desktop/Makefile b/android/qa/desktop/Makefile
index 375bb82..1dd0d83 100644
--- a/android/qa/desktop/Makefile
+++ b/android/qa/desktop/Makefile
@@ -38,6 +38,7 @@ buildrcs:
echo "OSL_SOCKET_PATH=$(APP_DATA_PATH)/files" >> 
assets/program/lofficerc
 # - this looks useful but breaks more than it fixes ...
 #  echo "DISABLE_EXTENSION_SYNCHRONIZATION=1" >> assets/program/lofficerc
+
 # fundamentalrc ini ...
echo "[Bootstrap]" > assets/program/fundamentalrc
echo "LO_LIB_DIR=file://$(APP_DATA_PATH)/lib/" >> 
assets/program/fundamentalrc
@@ -71,6 +72,22 @@ buildrcs:
echo "ProductKey=LibreOffice 3.5" >> assets/program/bootstraprc
echo "UserInstallation=file://$(APP_DATA_PATH)/files/.libreoffice" >> 
assets/program/bootstraprc
 
+# versionrc ini ...
+   echo "[Version]" > assets/program/versionrc
+   echo "AllLanguages=en-US" >> assets/program/versionrc
+   echo "BuildVersion=" >> assets/program/versionrc
+   echo "buildid=dead-beef" >> assets/program/versionrc
+   echo 
"ExtensionUpdateURL=http://updateexte.libreoffice.org/ExtensionUpdateService/check.Update";
 >> assets/program/versionrc
+   echo "ProductBuildid=3" >> assets/program/versionrc
+   echo "ProductMajor=360" >> assets/program/versionrc
+   echo "ProductMinor=1" >> assets/program/versionrc
+   echo "ProductSource=OOO350" >> assets/program/versionrc
+   echo "ReferenceOOoMajorMinor=3.6" >> assets/program/versionrc
+   echo "UpdateID=LibreOffice_3_en-US" >> assets/program/versionrc
+   echo "UpdateURL=" >> assets/program/versionrc
+   echo "UpdateUserAgent= (${buildid}; ${_OS}; ${_ARCH}; 
BundledLanguages=${AllLanguages})" >> assets/program/versionrc
+   echo "Vendor=SelfCompiledGit" >> assets/program/versionrc
+
 copy-stuff: buildrcs
 #
 # Copy shared libraries we need to libs/armeabi-v7a so that ant will
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] Changes to 'feature/android'

2012-01-25 Thread Michael Meeks
New branch 'feature/android' available with the following commits:
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: writerfilter/source

2012-01-25 Thread Miklos Vajna
 writerfilter/source/dmapper/DomainMapper.cxx |   25 -
 1 file changed, 25 deletions(-)

New commits:
commit 00db55ff835d78885bff83a372e601f64e732c6d
Author: Miklos Vajna 
Date:   Wed Jan 25 14:28:18 2012 +0100

writerfilter: drop unnecessary includes from DomainMapper.cxx

diff --git a/writerfilter/source/dmapper/DomainMapper.cxx 
b/writerfilter/source/dmapper/DomainMapper.cxx
index 0f01af2..851ded2 100644
--- a/writerfilter/source/dmapper/DomainMapper.cxx
+++ b/writerfilter/source/dmapper/DomainMapper.cxx
@@ -27,15 +27,11 @@
  /
 #include "PageBordersHandler.hxx"
 
-#include 
 #include 
 #include 
 #include 
-#include 
-#include 
 #include 
 #include 
-#include 
 #include 
 #include 
 #include 
@@ -49,25 +45,17 @@
 #include 
 #include 
 #include 
-#include 
-#include 
-#include 
-#include 
-#include 
 #include 
 #include 
 #include 
 #include 
 #include 
-#include 
-#include 
 #include 
 #include 
 #include 
 #include 
 #include 
 #include 
-#include 
 #include 
 #include 
 #include 
@@ -76,26 +64,13 @@
 #include 
 #include 
 #include 
-#include 
 #include 
 #include 
 
-#include 
 #include 
-#include 
-#include 
 #include 
-#include 
 #include 
 #include 
-#include 
-#include 
-
-#if OSL_DEBUG_LEVEL > 0
-#include 
-#endif
-
-#include 
 
 using namespace ::com::sun::star;
 using namespace ::rtl;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sc/source

2012-01-25 Thread Noel Power
 sc/source/ui/app/inputwin.cxx |   18 +++---
 sc/source/ui/inc/inputwin.hxx |2 ++
 2 files changed, 13 insertions(+), 7 deletions(-)

New commits:
commit 7580fff93292d08bc6f42792f256b832f5c4bad6
Author: Noel Power 
Date:   Wed Jan 25 12:36:17 2012 +

fix initial height of multiline input window

There is a hardcoded preferred height for the input window that was getting 
picked up becuase the result of GetTextHeight was just '1' ( due to no font 
being set up ) We shouldn't use a hardcoded value, we should always use the 
proper text height e.g. the result of a successfull call to  GetTextHeight() ( 
the patch makes sure we get a decent result from this call )

diff --git a/sc/source/ui/app/inputwin.cxx b/sc/source/ui/app/inputwin.cxx
index 1ae727c..3771d37 100644
--- a/sc/source/ui/app/inputwin.cxx
+++ b/sc/source/ui/app/inputwin.cxx
@@ -1128,6 +1128,15 @@ ScMultiTextWnd::ScMultiTextWnd( ScInputBarGroup* pParen, 
ScTabViewShell* pViewSh
 mnLastExpandedLines( INPUTWIN_MULTILINES ),
 mbInvalidate( false )
 {
+// Calculate the text height, need to set a font for that. Probably we 
could set the font
+// here ( on this Window ) and avoid the temp Window. OTOH vcl is such a 
mystery I prefer
+// to minimise possible unexpected side-affects this way
+Window aTmp(this, WB_BORDER );
+aTmp.SetFont(aTextFont);
+mnTextHeight = LogicToPixel(Size(0,aTmp.GetTextHeight())).Height() ;
+Size aBorder;
+aBorder = CalcWindowSize( aBorder);
+mnBorderHeight = aBorder.Height();
 nTextStartPos = TEXT_MULTI_STARTPOS;
 }
 
@@ -1158,13 +1167,8 @@ EditView* ScMultiTextWnd::GetEditView()
 
 long ScMultiTextWnd::GetPixelHeightForLines( long nLines )
 {
-long height = ( LogicToPixel(Size(0,GetTextHeight())).Height() );
-// need to figure out why GetTextHeight is not set up when I need it
-// some initialisation timing issue ?
-height = Max ( long( 14 ), height );
-// add padding ( for the borders of the window I guess ) otherwise we
-// chop slightly the top and bottom of whatever is in the inputbox
-return ( nLines *  height ) + 4;
+// add padding ( for the borders of the window )
+return ( nLines *  mnTextHeight ) + mnBorderHeight;
 }
 
 void ScMultiTextWnd::SetNumLines( long nLines )
diff --git a/sc/source/ui/inc/inputwin.hxx b/sc/source/ui/inc/inputwin.hxx
index eec7fed..185ac45 100644
--- a/sc/source/ui/inc/inputwin.hxx
+++ b/sc/source/ui/inc/inputwin.hxx
@@ -204,6 +204,8 @@ private:
 ScInputBarGroup& mrGroupBar;
 long mnLines;
 long mnLastExpandedLines;
+long mnTextHeight;
+long mnBorderHeight;
 bool mbInvalidate;
 };
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'libreoffice-3-5-0' - extensions/source scp2/source

2012-01-25 Thread Thorsten Behrens
 extensions/source/nsplugin/source/makefile.mk |4 
 scp2/source/ooo/common_brand.scp  |2 +-
 scp2/source/ooo/file_ooo.scp  |3 ---
 3 files changed, 1 insertion(+), 8 deletions(-)

New commits:
commit d4260355159afda5d91e9f9072e239ffe4ca7a2f
Author: Fridrich Å trba 
Date:   Wed Jan 25 10:20:07 2012 +0100

Fix building and packaging of the mozilla plugin

Signed-off-by: Tomas Chvatal 
Signed-off-by: Rene Engelhard 
Signed-off-by: Thorsten Behrens 

diff --git a/extensions/source/nsplugin/source/makefile.mk 
b/extensions/source/nsplugin/source/makefile.mk
index 3d52234..5b74764 100644
--- a/extensions/source/nsplugin/source/makefile.mk
+++ b/extensions/source/nsplugin/source/makefile.mk
@@ -36,8 +36,6 @@ USE_DEFFILE=TRUE
 
 .INCLUDE : settings.mk
 
-.IF "$(WITH_MOZILLA)" != "NO"
-
 .IF "$(SYSTEM_MOZILLA_HEADERS)" == "YES"
 INCPRE+=$(MOZILLA_HEADERS_CFLAGS)
 .ELSE
@@ -160,8 +158,6 @@ DEF2EXPORTFILE=exports.dxp
 DEF2EXPORTFILE=exports_wnt.dxp
 .ENDIF
 
-.ENDIF # $(WITH_MOZILLA) != "NO"
-
 # --- Targets --
 
 .INCLUDE : target.mk
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index 6c6fb66..aa8c77a 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -642,7 +642,7 @@ File gid_Brand_File_Bin_Libxml2
 End
 #endif
 
-#if !defined WITHOUT_MOZILLA && defined ENABLE_NSPLUGIN
+#ifdef ENABLE_NSPLUGIN
 File gid_Brand_File_Lib_Npsoplugin
 BIN_FILE_BODY;
 Name = SPECIAL_NAME(npsoplugin);
diff --git a/scp2/source/ooo/file_ooo.scp b/scp2/source/ooo/file_ooo.scp
index 091415b..e7bc85a 100644
--- a/scp2/source/ooo/file_ooo.scp
+++ b/scp2/source/ooo/file_ooo.scp
@@ -108,8 +108,6 @@ File gid_File_Basic_Tutorials
 Name = "basicsrvtutorials.zip";
 End
 
-#ifndef WITHOUT_MOZILLA
-
 #ifdef ENABLE_NSPLUGIN
 File gid_File_Exe_Nsplugin
 BIN_FILE_BODY;
@@ -122,7 +120,6 @@ File gid_File_Exe_Nsplugin
   #endif
 End
 #endif
-#endif
 
 #if !defined(WITHOUT_MOZILLA) && defined(UNX) && !defined(QUARTZ)
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: canvas/source

2012-01-25 Thread David Tardon
 canvas/source/tools/spriteredrawmanager.cxx |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

New commits:
commit 259e0dfc293d455f1ea777de132730f7e5fde22d
Author: David Tardon 
Date:   Wed Jan 25 12:34:23 2012 +0100

transparency gradient effect fade in is wrong (fdo#45219)

diff --git a/canvas/source/tools/spriteredrawmanager.cxx 
b/canvas/source/tools/spriteredrawmanager.cxx
index 91b81c5..72976c1 100644
--- a/canvas/source/tools/spriteredrawmanager.cxx
+++ b/canvas/source/tools/spriteredrawmanager.cxx
@@ -301,7 +301,8 @@ namespace canvas
aSortedSpriteVector.end(),
aUpdatableSprites.begin(),
aEnd,
-   ::std::back_insert_iterator< VectorOfSprites 
>(aUnchangedSprites) );
+   ::std::back_insert_iterator< VectorOfSprites 
>(aUnchangedSprites),
+   aSpriteComparator );
 
 // add each remaining unchanged sprite to connected ranges,
 // marked as "don't need update"
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 3 commits - basegfx/inc basegfx/Library_basegfx.mk basegfx/Package_inc.mk basegfx/source basegfx/StaticLibrary_basegfx_s.mk Makefile sc/source sd/source solenv/bin svx/inc svx

2012-01-25 Thread Jan Holesovsky
 Makefile|5 +
 basegfx/Library_basegfx.mk  |1 
 basegfx/Package_inc.mk  |1 
 basegfx/StaticLibrary_basegfx_s.mk  |1 
 basegfx/inc/basegfx/tools/zoomtools.hxx |   52 +++
 basegfx/source/tools/zoomtools.cxx  |  150 
 sc/source/ui/view/prevwsh.cxx   |6 -
 sc/source/ui/view/tabview.cxx   |7 -
 sd/source/ui/view/viewshel.cxx  |7 -
 solenv/bin/mkdocs.sh|2 
 svx/inc/svx/zoom_def.hxx|4 
 svx/source/stbctrls/zoomsliderctrl.cxx  |7 -
 sw/source/ui/uiview/viewport.cxx|7 -
 13 files changed, 226 insertions(+), 24 deletions(-)

New commits:
commit 3092e57f0c46ab1eafebcff0ad875acdd49d4e45
Author: Jan Holesovsky 
Date:   Wed Jan 25 12:35:29 2012 +0100

Add a note to the toplevel Makefile where to actually edit stuff.

diff --git a/Makefile b/Makefile
index 9f6c897..ed8e30e 100644
--- a/Makefile
+++ b/Makefile
@@ -26,6 +26,11 @@
 #
 #*
 
+# The real targets are in solenv/gbuild/Module.mk, resp.
+# solenv/gbuild/extensions/post_BuildplTargets.mk, this file only forwards
+# the calls - please look there if you want to edit what this toplevel
+# Makefile does.
+
 SRCDIR:=$(patsubst %/,%,$(dir $(realpath $(firstword $(MAKEFILE_LIST)
 
 ifeq ($(strip $(gb_SourceEnvAndRecurse_STAGE)),)
commit 1195d989d454a96e3b9fb0c0b6053db61b68f0b1
Author: Jan Holesovsky 
Date:   Wed Jan 25 12:34:56 2012 +0100

Allow killing 'make docs' by Ctrl-c.

diff --git a/solenv/bin/mkdocs.sh b/solenv/bin/mkdocs.sh
index 1112b0f..dbf4c46 100755
--- a/solenv/bin/mkdocs.sh
+++ b/solenv/bin/mkdocs.sh
@@ -89,7 +89,7 @@ do
   echo "Ref-Tags:   $DOXYGEN_REF_TAGFILES"
   echo "Title:  $DOXYGEN_PROJECTNAME"
 
-  nice -15 doxygen "$DOXYGEN_CFG"
+  nice -15 doxygen "$DOXYGEN_CFG" || exit 1
 
   # setup referenced tagfiles for next round
   DOXYGEN_REF_TAGFILES="$DOXYGEN_REF_TAGFILES 
$DOXYGEN_OUR_TAGFILE=$BASE_URL/$PROJECT/html"
commit 315d2ddc161e4b296febe9e54c3cfc9270310bfe
Author: Tim Hardeck 
Date:   Wed Jan 18 16:42:55 2012 +0100

optimized zoom to use more common intervals

Round zoom values beginning with 50 to a multiple of 5, with 100 to one
of 10, with 500 to one of 50 and with 1000 to one of 100.
The step 100 is enforced to have one fixed point.

diff --git a/basegfx/Library_basegfx.mk b/basegfx/Library_basegfx.mk
index fa0607b..fc6a479 100644
--- a/basegfx/Library_basegfx.mk
+++ b/basegfx/Library_basegfx.mk
@@ -66,6 +66,7 @@ $(eval $(call gb_Library_add_linked_libs,basegfx,\
 $(eval $(call gb_Library_add_exception_objects,basegfx,\
basegfx/source/tools/b2dclipstate \
basegfx/source/tools/canvastools \
+   basegfx/source/tools/zoomtools \
basegfx/source/tools/gradienttools \
basegfx/source/tools/keystoplerp \
basegfx/source/tools/liangbarsky \
diff --git a/basegfx/Package_inc.mk b/basegfx/Package_inc.mk
index 5767a8f..13b5ff8 100644
--- a/basegfx/Package_inc.mk
+++ b/basegfx/Package_inc.mk
@@ -37,6 +37,7 @@ $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tools/unopolypolygon.h
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tools/tools.hxx,basegfx/tools/tools.hxx))
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tools/unotools.hxx,basegfx/tools/unotools.hxx))
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tools/gradienttools.hxx,basegfx/tools/gradienttools.hxx))
+$(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tools/zoomtools.hxx,basegfx/tools/zoomtools.hxx))
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/numeric/ftools.hxx,basegfx/numeric/ftools.hxx))
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tuple/b3i64tuple.hxx,basegfx/tuple/b3i64tuple.hxx))
 $(eval $(call 
gb_Package_add_file,basegfx_inc,inc/basegfx/tuple/b3dtuple.hxx,basegfx/tuple/b3dtuple.hxx))
diff --git a/basegfx/StaticLibrary_basegfx_s.mk 
b/basegfx/StaticLibrary_basegfx_s.mk
index 79d6ed9..69616f7 100644
--- a/basegfx/StaticLibrary_basegfx_s.mk
+++ b/basegfx/StaticLibrary_basegfx_s.mk
@@ -72,6 +72,7 @@ $(WORKDIR)/CustomTarget/basegfx/source/%.cxx : 
$(SRCDIR)/basegfx/source/%.cxx
 $(eval $(call gb_StaticLibrary_add_generated_exception_objects,basegfx_s,\
CustomTarget/basegfx/source/tools/liangbarsky \
CustomTarget/basegfx/source/tools/canvastools \
+   CustomTarget/basegfx/source/tools/zoomtools \
CustomTarget/basegfx/source/tools/gradienttools \
CustomTarget/basegfx/source/tools/keystoplerp \
CustomTarget/basegfx/source/tools/unopolypolygon \
diff --git a/basegfx/inc/basegfx/tools/zoomtools.hxx 
b/basegfx/inc/basegfx/tools/zoomtools.hxx
new file mode 100644
index 000..566418d
--- /dev/null
+++ b/basegfx/inc/basegfx/tools/zoomtools.hxx
@@ -0,0 +1,52 @@
+/* -*- Mode: C++; tab-width: 4; indent-t

[Libreoffice-commits] .: 2 commits - scp2/source scp2/util sd/CppunitTest_sd_filters_test.mk sd/CppunitTest_sd_regression_test.mk

2012-01-25 Thread Thorsten Behrens
 scp2/source/canvas/makefile.mk   |5 +
 scp2/util/makefile.mk|5 +
 sd/CppunitTest_sd_filters_test.mk|2 +-
 sd/CppunitTest_sd_regression_test.mk |1 +
 4 files changed, 4 insertions(+), 9 deletions(-)

New commits:
commit 554bcf4205ede6ec3adb9f39e676b77054b1e8a1
Author: Riccardo Magliocchetti 
Date:   Wed Jan 25 12:00:45 2012 +0100

Fix file not found: cairocanvas.uno.so in smoketestoo_native

diff --git a/scp2/source/canvas/makefile.mk b/scp2/source/canvas/makefile.mk
index 7ce0257..d0d8362 100644
--- a/scp2/source/canvas/makefile.mk
+++ b/scp2/source/canvas/makefile.mk
@@ -41,12 +41,9 @@ PARFILES= canvascommons.par  \
   vclcanvas.par \
  mtfrenderer.par
 
-.IF "$(GUI)"=="UNX"
-#X11 MacOSX has no cairo-canvas
-.IF "$(OS)" != "MACOSX" || "$(GUIBASE)" == "aqua"
+.IF "$(ENABLE_CAIRO_CANVAS)"=="TRUE"
 PARFILES+= cairocanvas.par
 .ENDIF
-.ENDIF
 
 .IF "$(ENABLE_DIRECTX)" != ""
 .IF "$(USE_DIRECTX5)" != ""
diff --git a/scp2/util/makefile.mk b/scp2/util/makefile.mk
index 74b45a8..7de0c6c 100644
--- a/scp2/util/makefile.mk
+++ b/scp2/util/makefile.mk
@@ -209,12 +209,9 @@ SCP1FILES += \
  vclcanvas.par \
 mtfrenderer.par
 
-.IF "$(GUI)"=="UNX"
-#X11 MacOSX has no cairo-canvas
-.IF "$(OS)" != "MACOSX" || "$(GUIBASE)" == "aqua"
+.IF "$(ENABLE_CAIRO_CANVAS)"=="TRUE"
 SCP1FILES += cairocanvas.par
 .ENDIF
-.ENDIF
 
 .IF "$(ENABLE_ONLINE_UPDATE)"!=""
 SCP1FILES += \
commit 400ad00534afbbc93de9fd0835e487980f85a336
Author: Thorsten Behrens 
Date:   Wed Jan 25 11:52:00 2012 +0100

Put font embedding disable to correct unit test

diff --git a/sd/CppunitTest_sd_filters_test.mk 
b/sd/CppunitTest_sd_filters_test.mk
index 5b89b8f..b4de440 100644
--- a/sd/CppunitTest_sd_filters_test.mk
+++ b/sd/CppunitTest_sd_filters_test.mk
@@ -123,7 +123,7 @@ $(eval $(call 
gb_CppunitTest_add_old_components,sd_filters_test,\
 $(eval $(call gb_CppunitTest_set_args,sd_filters_test,\
 --headless \
 --protector unoexceptionprotector$(gb_Library_DLLEXT) 
unoexceptionprotector \
-"-env:CONFIGURATION_LAYERS=xcsxcu:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry) 
-env:SVG_DISABLE_FONT_EMBEDDING=YEAH module:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry/spool)" \
+"-env:CONFIGURATION_LAYERS=xcsxcu:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry) module:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry/spool)" \
 ))
 # .../spool is required for the (somewhat strange) filter configuration
 
diff --git a/sd/CppunitTest_sd_regression_test.mk 
b/sd/CppunitTest_sd_regression_test.mk
index 1c3b089..8e56336 100644
--- a/sd/CppunitTest_sd_regression_test.mk
+++ b/sd/CppunitTest_sd_regression_test.mk
@@ -130,6 +130,7 @@ $(eval $(call gb_CppunitTest_set_args,sd_regression_test,\
 --headless \
 --protector unoexceptionprotector$(gb_Library_DLLEXT) 
unoexceptionprotector \
 "-env:CONFIGURATION_LAYERS=xcsxcu:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry) module:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/xml/registry/spool) xcsxcu:$(call 
gb_CppunitTarget__make_url,$(OUTDIR)/unittest/registry)" \
+"-env:SVG_DISABLE_FONT_EMBEDDING=YEAH" \
 ))
 # .../spool is required for the (somewhat strange) filter configuration
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: vcl/source

2012-01-25 Thread Stephan Bergmann
 vcl/source/gdi/gdimtf.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 15e67c8fbda050ba8288619e77ade1e52451
Author: Stephan Bergmann 
Date:   Wed Jan 25 10:49:28 2012 +0100

Clean up (don't bind retval temporaries to references).

diff --git a/vcl/source/gdi/gdimtf.cxx b/vcl/source/gdi/gdimtf.cxx
index f6cb49c..e9ac49e 100644
--- a/vcl/source/gdi/gdimtf.cxx
+++ b/vcl/source/gdi/gdimtf.cxx
@@ -449,13 +449,13 @@ bool GDIMetaFile::ImplPlayWithRenderer( OutputDevice* 
pOut, const Point& rPos, S
 
 try
 {
-const uno::Reference& xCanvas = win->GetCanvas ();
+uno::Reference xCanvas = win->GetCanvas ();
 
 if (!xCanvas.is())
 return false;
 
 Size aSize (rDestSize.Width () + 1, rDestSize.Height () + 1);
-const uno::Reference& xBitmap = xCanvas->getDevice 
()->createCompatibleAlphaBitmap (vcl::unotools::integerSize2DFromSize( aSize));
+uno::Reference xBitmap = xCanvas->getDevice 
()->createCompatibleAlphaBitmap (vcl::unotools::integerSize2DFromSize( aSize));
 uno::Reference< lang::XMultiServiceFactory > xFactory = 
vcl::unohelper::GetMultiServiceFactory();
 if( xFactory.is() && xBitmap.is () )
 {
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'libreoffice-3-5' - extensions/source scp2/source

2012-01-25 Thread Fridrich Strba
 extensions/source/nsplugin/source/makefile.mk |4 
 scp2/source/ooo/common_brand.scp  |2 +-
 scp2/source/ooo/file_ooo.scp  |3 ---
 3 files changed, 1 insertion(+), 8 deletions(-)

New commits:
commit 04caf572d6847ff1efce2942b1ba5058797aef9c
Author: Fridrich Å trba 
Date:   Wed Jan 25 10:20:07 2012 +0100

Fix building and packaging of the mozilla plugin

signed-off-by: Tomas Chvatal 

diff --git a/extensions/source/nsplugin/source/makefile.mk 
b/extensions/source/nsplugin/source/makefile.mk
index 3d52234..5b74764 100644
--- a/extensions/source/nsplugin/source/makefile.mk
+++ b/extensions/source/nsplugin/source/makefile.mk
@@ -36,8 +36,6 @@ USE_DEFFILE=TRUE
 
 .INCLUDE : settings.mk
 
-.IF "$(WITH_MOZILLA)" != "NO"
-
 .IF "$(SYSTEM_MOZILLA_HEADERS)" == "YES"
 INCPRE+=$(MOZILLA_HEADERS_CFLAGS)
 .ELSE
@@ -160,8 +158,6 @@ DEF2EXPORTFILE=exports.dxp
 DEF2EXPORTFILE=exports_wnt.dxp
 .ENDIF
 
-.ENDIF # $(WITH_MOZILLA) != "NO"
-
 # --- Targets --
 
 .INCLUDE : target.mk
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index 6c6fb66..aa8c77a 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -642,7 +642,7 @@ File gid_Brand_File_Bin_Libxml2
 End
 #endif
 
-#if !defined WITHOUT_MOZILLA && defined ENABLE_NSPLUGIN
+#ifdef ENABLE_NSPLUGIN
 File gid_Brand_File_Lib_Npsoplugin
 BIN_FILE_BODY;
 Name = SPECIAL_NAME(npsoplugin);
diff --git a/scp2/source/ooo/file_ooo.scp b/scp2/source/ooo/file_ooo.scp
index 091415b..e7bc85a 100644
--- a/scp2/source/ooo/file_ooo.scp
+++ b/scp2/source/ooo/file_ooo.scp
@@ -108,8 +108,6 @@ File gid_File_Basic_Tutorials
 Name = "basicsrvtutorials.zip";
 End
 
-#ifndef WITHOUT_MOZILLA
-
 #ifdef ENABLE_NSPLUGIN
 File gid_File_Exe_Nsplugin
 BIN_FILE_BODY;
@@ -122,7 +120,6 @@ File gid_File_Exe_Nsplugin
   #endif
 End
 #endif
-#endif
 
 #if !defined(WITHOUT_MOZILLA) && defined(UNX) && !defined(QUARTZ)
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: vcl/source

2012-01-25 Thread Radek Doulík
 vcl/source/gdi/gdimtf.cxx |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 9b20b8e9c6a177b98b86f227e2e5d056563ec9d5
Author: Radek Doulik 
Date:   Wed Jan 25 09:29:00 2012 +0100

Revert "fix rendering of metafiles embedded in emf+"

This reverts commit f7b6cd87f78b786b59984e5b3c8a5a78f0ed7a94.

diff --git a/vcl/source/gdi/gdimtf.cxx b/vcl/source/gdi/gdimtf.cxx
index 49d3bbb..f6cb49c 100644
--- a/vcl/source/gdi/gdimtf.cxx
+++ b/vcl/source/gdi/gdimtf.cxx
@@ -406,9 +406,9 @@ void GDIMetaFile::Play( OutputDevice* pOut, size_t nPos )
 pOut->SetLayoutMode( 0 );
 pOut->SetDigitLanguage( 0 );
 
-OSL_TRACE("GDIMetaFile::Play on device of size: %d x %d", 
pOut->GetOutputSizePixel().Width(), pOut->GetOutputSizePixel().Height());
-if( !ImplPlayWithRenderer( pOut, Point(0,0), 
pOut->GetOutputSizePixel() ) ) {
-for( size_t nCurPos = nCurrentActionElement; nCurPos < nPos; 
nCurPos++ )
+for( size_t nCurPos = nCurrentActionElement; nCurPos < nPos; nCurPos++ 
)
+{
+if( !Hook() )
 {
 MetaCommentAction* pCommentAct = 
static_cast(pAction);
 if( pAction->GetType() == META_COMMENT_ACTION &&
@@ -608,7 +608,7 @@ void GDIMetaFile::Play( OutputDevice* pOut, const Point& 
rPos,
 {
 GDIMetaFile*pMtf = pOut->GetConnectMetaFile();
 
-if( bUseCanvas && ImplPlayWithRenderer( pOut, rPos, aDestSize ) )
+if( bUseCanvas && !pMtf && ImplPlayWithRenderer( pOut, rPos, aDestSize 
) )
 return;
 
 Size aTmpPrefSize( pOut->LogicToPixel( GetPrefSize(), aDrawMap ) );
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: android/qa

2012-01-25 Thread Tor Lillqvist
 android/qa/simple/Makefile |3 +++
 1 file changed, 3 insertions(+)

New commits:
commit 7175129b2d8549c5e18e1222c943ddda5f2e9ee5
Author: Tor Lillqvist 
Date:   Wed Jan 25 09:53:19 2012 +0200

Add notice that the android/qa/simple directory has not been maintained

diff --git a/android/qa/simple/Makefile b/android/qa/simple/Makefile
index 70fb5c6..8007084 100644
--- a/android/qa/simple/Makefile
+++ b/android/qa/simple/Makefile
@@ -1,3 +1,6 @@
+THIS DIRECTORY IS UNMAINTAINED AND PRESUMABLY BROKEN ALREADY
+
+
 include ../../../config_host.mk
 
 # The package of this app
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java 
b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
index a1f3dfb..fe67abc 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * 
 * The following files used by this test :
 * 
 *   ScDDELinksObj.sdc  : the predefined testdocument 
 *  
 * @see com.sun.star.sheet.DDELink
 * @see com.sun.star.container.XNamed
@@ -145,7 +145,7 @@ public class ScDDELinkObj extends TestCase {
 XMultiServiceFactory oMSF = (XMultiServiceFactory)Param.getMSF();
 
 // load the predefined testdocument
-String testdoc = util.utils.getFullTestURL("ScDDELinksObj.sdc");
+String testdoc = util.utils.getFullTestURL("ScDDELinksObj.ods");
 try {
 oDoc = SOfficeFactory.getFactory(oMSF).loadDocument(testdoc);
 } catch (com.sun.star.lang.IllegalArgumentException e) {
@@ -183,7 +183,7 @@ public class ScDDELinkObj extends TestCase {
 log.println("filling some cells");
 String sAppl = "soffice";
 String sItem = "Sheet1.A1";
-testdoc = util.utils.getFullTestDocName("ScDDELinksObj.sdc");
+testdoc = util.utils.getFullTestDocName("ScDDELinksObj.ods");
 try {
 oSheet.getCellByPosition(5, 5).setFormula(
 "=DDE(\""+ sAppl +"\";\""+testdoc+"\";\""+ sItem +"\"");
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * The following files used by this test :
 * 
-*   ScDDELinksObj.sdc  : the predefined testdocument 
+*   ScDDELinksObj.ods  : the predefined testdocument 
 *  
 * @see com.sun.star.sheet.DDELink
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java 
b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
index fbcb724..d37579c 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * 
 * The following files used by this test :
 * 
 *   ScDDELinksObj.sdc  : the predefined testdocument 
 *  
 * @see com.sun.star.sheet.DDELinks
 * @see com.sun.star.container.XNameAccess
@@ -124,7 +124,7 @@ public class ScDDELinksObj extends TestCase {
 XMultiServiceFactory oMSF = (XMultiServiceFactory)Param.getMSF();
 
 // load the predefined testdocument
-String testdoc = utils.getFullTestURL("ScDDELinksObj.sdc");
+String testdoc = utils.getFullTestURL("ScDDELinksObj.ods");
 try {
 oDoc = SOfficeFactory.getFactory(oMSF).loadDocument(testdoc);
 } catch (com.sun.star.lang.IllegalArgumentException e) {
@@ -159,7 +159,7 @@ public class ScDDELinksObj extends TestCase {
 throw new StatusException("Couldn't get a spreadsheet", e);
 }
 
-testdoc = utils.getFullTestDocName("ScDDELinksObj.sdc");
+testdoc = utils.getFullTestDocName("ScDDELinksObj.ods");
 log.println("filling some cells");
 try {
 oSheet.getCellByPosition(5, 5).setFormula(
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * The following files used by this test :
 * 
-*   ScDDELinksObj.sdc  : the predefined testdocument 
+*   ScDDELinksObj.ods  : the predefined testdocument 
 *  
 * @see com.sun.star.sheet.DDELinks